@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # SPDX-FileCopyrightText: 2024 Jean-Baptiste Mardelle <jb@kdenlive.org>
-# SPDX-FileCopyrightText: 2022 Julius Künzel <jk.kdedev@smartlab.uber.space>
+# SPDX-FileCopyrightText: 2022 Julius Künzel <julius.kuenzel@kde.org>
 # SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 import sys
@@ -36,7 +36,10 @@ missing = set()
 
 for arg in sys.argv[1:]:
     if not arg.startswith("--"):
-        required.add(arg.lower())
+        if arg.endswith(".txt"):
+            required.add(arg)
+        else:
+            required.add(arg.lower())
 
 if len(required) == 0:
     print_help()
@@ -62,19 +65,25 @@ elif '--install' in sys.argv and len(sys.argv) > 1:
         for m in missing:
             try:
                 if m.endswith(".txt"):
-                    subprocess.check_call([python, '-m', 'pip', 'install', '-r', m])
+                    subprocess.check_call([python, '-m', 'pip', 'install', '-r', m, '--no-cache-dir'])
                 else:
-                    subprocess.check_call([python, '-m', 'pip', 'install', m])
+                    subprocess.check_call([python, '-m', 'pip', 'install', m, '--no-cache-dir'])
             except:
                 print("failed installing ", m)
 elif '--upgrade' in sys.argv:
     # update modules
-    print("Updating packages: ", required)
+    # print("Updating packages: ", required)
     python = sys.executable
+    upgradable = normalizedInstalled - required
+    for u in upgradable:
+        try:
+            subprocess.check_call([python, '-m', 'pip', 'install', '--upgrade', u])
+        except:
+            print("failed upgrading ", u)
     for r in required:
         try:
             if r.endswith(".txt"):
-                subprocess.check_call([python, '-m', 'pip', 'install', '--force-reinstall', '-r', r])
+                subprocess.check_call([python, '-m', 'pip', 'install', '--upgrade', '-r', r])
             else:
                 subprocess.check_call([python, '-m', 'pip', 'install', '--upgrade', r])
         except:
@@ -83,8 +92,8 @@ elif '--details' in sys.argv:
     # check modules version
     python = sys.executable
     for m in missing:
-        print("Name: ", m, " Version: missing ")
-    subprocess.check_call([python, '-m', 'pip', 'show', *required])
+        print(m, "==missing", file=sys.stdout,flush=True)
+    subprocess.check_call([python, '-m', 'pip', 'freeze'])
 else:
     print_help()
     sys.exit("Error: You need to provide a mode")
