@@ -121,7 +121,7 @@ bool KeyframeModelList::applyOperation(const std::function<bool(std::shared_ptr<
     return res;
 }
 
-bool KeyframeModelList::addKeyframe(GenTime pos, KeyframeType type)
+bool KeyframeModelList::addKeyframe(GenTime pos, KeyframeType::KeyframeEnum type)
 {
     QWriteLocker locker(&m_lock);
     Q_ASSERT(m_parameters.size() > 0);
@@ -139,7 +139,7 @@ bool KeyframeModelList::addKeyframe(GenTime pos, KeyframeType type)
         double fps = pCore->getCurrentFps();
         GenTime offset = pos - GenTime(pCore->getItemIn(id), fps);
         QList<std::shared_ptr<KeyframeModelList>> groupedKfrModels = pCore->getGroupKeyframeModels(id, getAssetId());
-        for (auto km : groupedKfrModels) {
+        for (auto km : std::as_const(groupedKfrModels)) {
             GenTime posWithOffset = GenTime(pCore->getItemIn(km->getOwnerId()), fps) + offset;
             if (posWithOffset > GenTime(pCore->getItemDuration(km->getOwnerId()), fps)) {
                 // Keyframe is outside object, don't process
@@ -209,7 +209,7 @@ bool KeyframeModelList::addKeyframe(int frame, double val)
         } else {
             value = param->getInterpolatedValue(pos);
         }
-        return param->addKeyframe(pos, KeyframeType(KdenliveSettings::defaultkeyframeinterp()), value, true, undo, redo);
+        return param->addKeyframe(pos, KeyframeType::KeyframeEnum(KdenliveSettings::defaultkeyframeinterp()), value, true, undo, redo);
     };
     const QString opText = update ? i18n("Change keyframe type") : i18n("Add keyframe");
     Fun undo = []() { return true; };
@@ -220,7 +220,7 @@ bool KeyframeModelList::addKeyframe(int frame, double val)
         double fps = pCore->getCurrentFps();
         GenTime offset = pos - GenTime(pCore->getItemIn(id), fps);
         QList<std::shared_ptr<KeyframeModelList>> groupedKfrModels = pCore->getGroupKeyframeModels(id, getAssetId());
-        for (auto km : groupedKfrModels) {
+        for (auto km : std::as_const(groupedKfrModels)) {
             GenTime posWithOffset = GenTime(pCore->getItemIn(km->getOwnerId()), fps) + offset;
             auto op2 = [km, posWithOffset, val, pType](std::shared_ptr<KeyframeModel> param, bool, Fun &undo, Fun &redo) {
                 QVariant value;
@@ -243,7 +243,7 @@ bool KeyframeModelList::addKeyframe(int frame, double val)
                 } else {
                     value = param->getInterpolatedValue(posWithOffset);
                 }
-                return param->addKeyframe(posWithOffset, KeyframeType(KdenliveSettings::defaultkeyframeinterp()), value, true, undo, redo);
+                return param->addKeyframe(posWithOffset, KeyframeType::KeyframeEnum(KdenliveSettings::defaultkeyframeinterp()), value, true, undo, redo);
             };
             res = res && km->applyOperation(op2, undo, redo);
         }
@@ -272,7 +272,7 @@ bool KeyframeModelList::removeKeyframe(GenTime pos)
         double fps = pCore->getCurrentFps();
         GenTime offset = pos - GenTime(pCore->getItemIn(id), fps);
         QList<std::shared_ptr<KeyframeModelList>> groupedKfrModels = pCore->getGroupKeyframeModels(id, getAssetId());
-        for (auto km : groupedKfrModels) {
+        for (auto km : std::as_const(groupedKfrModels)) {
             GenTime posWithOffset = GenTime(pCore->getItemIn(km->getOwnerId()), fps) + offset;
             if (posWithOffset > GenTime(pCore->getItemDuration(km->getOwnerId()), fps)) {
                 // Keyframe is outside object, don't process
@@ -591,7 +591,7 @@ bool KeyframeModelList::updateKeyframeType(GenTime pos, int type, const QPersist
     return res;
 }
 
-KeyframeType KeyframeModelList::keyframeType(GenTime pos) const
+KeyframeType::KeyframeEnum KeyframeModelList::keyframeType(GenTime pos) const
 {
     QWriteLocker locker(&m_lock);
     if (singleKeyframe()) {
@@ -706,7 +706,7 @@ void KeyframeModelList::setParametersFromTask(const paramVector &params)
         const QModelIndex ix = ptr->getParamIndexFromName(params.first().first);
         if (ix.isValid()) {
             QList<GenTime> kfrs = m_parameters.at(ix)->getKeyframePos();
-            auto type = KeyframeType(KdenliveSettings::defaultkeyframeinterp());
+            auto type = KeyframeType::KeyframeEnum(KdenliveSettings::defaultkeyframeinterp());
             for (const auto &p : m_parameters) {
                 const QString paramName = ptr->data(p.first, AssetParameterModel::NameRole).toString();
                 if (!updatedNames.contains(paramName)) {
@@ -803,7 +803,7 @@ void KeyframeModelList::moveKeyframes(int oldIn, int in, Fun &undo, Fun &redo)
         std::sort(positions.begin(), positions.end());
     }
     for (const auto &param : m_parameters) {
-        for (auto frame : qAsConst(positions)) {
+        for (auto frame : std::as_const(positions)) {
             param.second->moveKeyframe(frame, frame + offset, QVariant(), undo, redo);
         }
     }
@@ -826,7 +826,7 @@ void KeyframeModelList::resizeKeyframes(int oldIn, int oldOut, int in, int out,
                     QVariant value = param.second->getInterpolatedValue(new_in);
                     param.second->updateKeyframe(old_in, value, undo, redo);
                 }
-                for (auto frame : qAsConst(positions)) {
+                for (auto frame : std::as_const(positions)) {
                     if (new_in > GenTime()) {
                         if (frame > new_in) {
                             param.second->moveKeyframe(frame, frame - new_in, QVariant(), undo, redo);
@@ -845,7 +845,7 @@ void KeyframeModelList::resizeKeyframes(int oldIn, int oldOut, int in, int out,
             GenTime old_in(oldIn, pCore->getCurrentFps());
             GenTime new_in(in, pCore->getCurrentFps());
             Keyframe kf = getKeyframe(old_in, &ok);
-            KeyframeType type = kf.second;
+            KeyframeType::KeyframeEnum type = kf.second;
             getKeyframe(new_in, &ok2);
             if (!ok2) {
                 // Add new in point
@@ -882,7 +882,7 @@ void KeyframeModelList::resizeKeyframes(int oldIn, int oldOut, int in, int out,
         GenTime old_out(oldOut, pCore->getCurrentFps());
         GenTime new_out(out, pCore->getCurrentFps());
         Keyframe kf = getKeyframe(old_out, &ok);
-        KeyframeType type = kf.second;
+        KeyframeType::KeyframeEnum type = kf.second;
         getKeyframe(new_out, &ok2);
         // Check keyframes after last position
         bool ok3;
@@ -918,7 +918,7 @@ void KeyframeModelList::resizeKeyframes(int oldIn, int oldOut, int in, int out,
             for (const auto &param : m_parameters) {
                 QVariant value = param.second->getInterpolatedValue(new_out);
                 param.second->addKeyframe(new_out, type, value, true, undo, redo);
-                for (auto frame : qAsConst(positions)) {
+                for (auto frame : std::as_const(positions)) {
                     param.second->removeKeyframe(frame, undo, redo);
                 }
             }
@@ -942,7 +942,7 @@ void KeyframeModelList::checkConsistency()
         }
     }
     Fun local_update = []() { return true; };
-    auto type = KeyframeType(KdenliveSettings::defaultkeyframeinterp());
+    auto type = KeyframeType::KeyframeEnum(KdenliveSettings::defaultkeyframeinterp());
     for (const auto &param : m_parameters) {
         QList<GenTime> list = param.second->getKeyframePos();
         for (auto &time : fullList) {
