@@ -1,5 +1,5 @@
 /*
-SPDX-FileCopyrightText: 2021 Julius Künzel <jk.kdedev@smartlab.uber.space>
+SPDX-FileCopyrightText: 2021 Julius Künzel <julius.kuenzel@kde.org>
 This file is part of Kdenlive. See www.kdenlive.org.
 
 SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
@@ -51,7 +51,7 @@ void RectHelper::refreshParams(int pos)
 {
     int x = 0, y = 0, w = 500, h = 500;
     QSize frameSize = pCore->getCurrentFrameSize();
-    for (const auto &ix : qAsConst(m_indexes)) {
+    for (const auto &ix : std::as_const(m_indexes)) {
         auto type = m_model->data(ix, AssetParameterModel::TypeRole).value<ParamType>();
         if (type != ParamType::KeyframeParam) {
             continue;
