@@ -39,6 +39,6 @@ public:
      */
     void refreshParams(int pos) override;
 
-private slots:
+private Q_SLOTS:
     void slotUpdateFromMonitorRect(const QRect &rect);
 };
