@@ -207,20 +207,12 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
     double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
     double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    int pos = int(((event->x() - m_offset) / zoomFactor + zoomStart) / m_scale);
-#else
     int pos = int(((event->position().x() - m_offset) / zoomFactor + zoomStart) / m_scale);
-#endif
     pos = qBound(0, pos, m_duration - 1);
     m_moveKeyframeMode = false;
     m_keyframeZonePress = false;
     if (event->button() == Qt::LeftButton) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if (event->y() < m_lineHeight) {
-#else
         if (event->position().y() < m_lineHeight) {
-#endif
             // mouse click in keyframes area
             bool ok;
             GenTime position(pos + offset, pCore->getCurrentFps());
@@ -262,18 +254,10 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
             m_model->setSelectedKeyframes({});
             m_model->setActiveKeyframe(-1);
             m_currentKeyframeOriginal = -1;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        } else if (event->y() > m_zoomHeight + 2) {
-#else
         } else if (event->position().y() > m_zoomHeight + 2) {
-#endif
             // click on zoom area
             if (m_hoverZoom) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                m_clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset);
-#else
                 m_clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset);
-#endif
             }
             // When not zoomed, allow seek by clicking on zoombar
             if (qFuzzyCompare(m_zoomFactor, 1.) && pos != m_position && !m_hoverZoomIn && !m_hoverZoomOut) {
@@ -281,11 +265,7 @@ void KeyframeView::mousePressEvent(QMouseEvent *event)
             }
             return;
         }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    } else if (event->button() == Qt::RightButton && event->y() > m_zoomHeight + 2) {
-#else
     } else if (event->button() == Qt::RightButton && event->position().y() > m_zoomHeight + 2) {
-#endif
         // Right click on zoom, switch between no zoom and last zoom status
         if (m_zoomHandle == QPointF(0, 1)) {
             if (!m_lastZoomHandle.isNull()) {
@@ -312,41 +292,28 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
     double zoomStart = m_zoomHandle.x() * (width() - 2 * m_offset);
     double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
     double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    int pos = int(((double(event->x()) - m_offset) / zoomFactor + zoomStart) / m_scale);
-#else
     int pos = int(((double(event->position().x()) - m_offset) / zoomFactor + zoomStart) / m_scale);
-#endif
+    if (m_duration <= 1) {
+        return;
+    }
     pos = qBound(0, pos, m_duration - 1);
     GenTime position(pos + offset, pCore->getCurrentFps());
     if ((event->buttons() & Qt::LeftButton) != 0u) {
         if (m_hoverZoomIn || m_hoverZoomOut || m_hoverZoom) {
             // Moving zoom handles
             if (m_hoverZoomIn) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                m_zoomHandle.setX(qMin(qMax(0., double(event->x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.y() - 0.015));
-#else
                 m_zoomHandle.setX(qMin(qMax(0., double(event->position().x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.y() - 0.015));
-#endif
                 update();
                 return;
             }
             if (m_hoverZoomOut) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                m_zoomHandle.setY(qMax(qMin(1., double(event->x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.x() + 0.015));
-#else
                 m_zoomHandle.setY(qMax(qMin(1., double(event->position().x() - m_offset) / (width() - 2 * m_offset)), m_zoomHandle.x() + 0.015));
-#endif
                 update();
                 return;
             }
             // moving zoom zone
             if (m_hoverZoom) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                double clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset) - m_clickOffset;
-#else
                 double clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset) - m_clickOffset;
-#endif
                 double newX = m_zoomHandle.x() + clickOffset;
                 if (newX < 0) {
                     clickOffset = -m_zoomHandle.x();
@@ -358,11 +325,7 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
                     newY = 1;
                     newX = m_zoomHandle.x() + clickOffset;
                 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                m_clickOffset = (double(event->x()) - m_offset) / (width() - 2 * m_offset);
-#else
                 m_clickOffset = (double(event->position().x()) - m_offset) / (width() - 2 * m_offset);
-#endif
                 m_zoomHandle = QPointF(newX, newY);
                 update();
             }
@@ -435,11 +398,7 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
         }
         return;
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (event->y() < m_lineHeight) {
-#else
     if (event->position().y() < m_lineHeight) {
-#endif
         bool ok;
         auto keyframe = m_model->getClosestKeyframe(position, &ok);
         if (ok && qAbs(((position.frames(pCore->getCurrentFps()) - keyframe.first.frames(pCore->getCurrentFps())) * m_scale) * m_zoomFactor) <
@@ -454,15 +413,9 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             return;
         }
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (event->y() > m_zoomHeight + 2) {
-        // Moving in zoom area
-        if (qAbs(event->x() - m_offset - (m_zoomHandle.x() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
-#else
     if (event->position().y() > m_zoomHeight + 2) {
         // Moving in zoom area
         if (qAbs(event->position().x() - m_offset - (m_zoomHandle.x() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
-#endif
             setCursor(Qt::SizeHorCursor);
             m_hoverZoomIn = true;
             m_hoverZoomOut = false;
@@ -470,11 +423,7 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             update();
             return;
         }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if (qAbs(event->x() - m_offset - (m_zoomHandle.y() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
-#else
         if (qAbs(event->position().x() - m_offset - (m_zoomHandle.y() * (width() - 2 * m_offset))) < QApplication::startDragDistance()) {
-#endif
             setCursor(Qt::SizeHorCursor);
             m_hoverZoomOut = true;
             m_hoverZoomIn = false;
@@ -482,13 +431,8 @@ void KeyframeView::mouseMoveEvent(QMouseEvent *event)
             update();
             return;
         }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if (m_zoomHandle != QPointF(0, 1) && event->x() > m_offset + (m_zoomHandle.x() * (width() - 2 * m_offset)) &&
-            event->x() < m_offset + (m_zoomHandle.y() * (width() - 2 * m_offset))) {
-#else
         if (m_zoomHandle != QPointF(0, 1) && event->position().x() > m_offset + (m_zoomHandle.x() * (width() - 2 * m_offset)) &&
             event->position().x() < m_offset + (m_zoomHandle.y() * (width() - 2 * m_offset))) {
-#endif
             setCursor(Qt::PointingHandCursor);
             m_hoverZoom = true;
             m_hoverZoomIn = false;
@@ -555,20 +499,12 @@ void KeyframeView::mouseReleaseEvent(QMouseEvent *event)
 
 void KeyframeView::mouseDoubleClickEvent(QMouseEvent *event)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (event->button() == Qt::LeftButton && event->y() < m_lineHeight) {
-#else
     if (event->button() == Qt::LeftButton && event->position().y() < m_lineHeight) {
-#endif
         int offset = pCore->getItemIn(m_model->getOwnerId());
         double zoomStart = m_zoomHandle.x() * (width() - 2 * m_offset);
         double zoomEnd = m_zoomHandle.y() * (width() - 2 * m_offset);
         double zoomFactor = (width() - 2 * m_offset) / (zoomEnd - zoomStart);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        int pos = int(((event->x() - m_offset) / zoomFactor + zoomStart) / m_scale);
-#else
         int pos = int(((event->position().x() - m_offset) / zoomFactor + zoomStart) / m_scale);
-#endif
         pos = qBound(0, pos, m_duration - 1);
         GenTime position(pos + offset, pCore->getCurrentFps());
         bool ok;
@@ -585,7 +521,7 @@ void KeyframeView::mouseDoubleClickEvent(QMouseEvent *event)
         }
 
         // add new keyframe
-        m_model->addKeyframe(position, KeyframeType(KdenliveSettings::defaultkeyframeinterp()));
+        m_model->addKeyframe(position, KeyframeType::KeyframeEnum(KdenliveSettings::defaultkeyframeinterp()));
     } else {
         QWidget::mouseDoubleClickEvent(event);
     }
