@@ -13,6 +13,7 @@
 #include <memory>
 
 class QVBoxLayout;
+class QFormLayout;
 class QMenu;
 class QActionGroup;
 class AbstractParamWidget;
@@ -34,6 +35,7 @@ public:
 
     /** Set the widget to display no model (this yield ownership on the smart-ptr)*/
     void unsetModel();
+    void disconnectKeyframeWidget();
 
     /** Returns the preferred widget height */
     int contentHeight() const;
@@ -68,7 +70,7 @@ protected:
         It basically instructs the widgets in the given range to be refreshed */
     void refresh(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles);
 
-    QVBoxLayout *m_lay;
+    QFormLayout *m_lay;
     /** @brief Protect from concurrent operations
      **/
     QMutex m_lock;
@@ -101,6 +103,7 @@ Q_SIGNALS:
     void nextKeyframe();
     void previousKeyframe();
     void addRemoveKeyframe();
+    void saveEffect();
     /** @brief Used to pass a standard action like copy or paste to the effect stack widget */
     void sendStandardCommand(int command);
 };
