@@ -15,14 +15,11 @@ KeywordParamWidget::KeywordParamWidget(std::shared_ptr<AssetParameterModel> mode
     QString comment = m_model->data(m_index, AssetParameterModel::CommentRole).toString();
     setToolTip(comment);
 
-    // setup the name
-    label->setText(m_model->data(m_index, Qt::DisplayRole).toString());
-
     QStringList kwrdValues = m_model->data(m_index, AssetParameterModel::ListValuesRole).toStringList();
     QStringList kwrdNames = m_model->data(m_index, AssetParameterModel::ListNamesRole).toStringList();
     comboboxwidget->addItems(kwrdNames);
     int i = 0;
-    for (const QString &keywordVal : qAsConst(kwrdValues)) {
+    for (const QString &keywordVal : std::as_const(kwrdValues)) {
         if (i >= comboboxwidget->count()) {
             break;
         }
