@@ -6,40 +6,36 @@
 #include "switchparamwidget.hpp"
 #include "assets/model/assetparametermodel.hpp"
 
+#include <QCheckBox>
+#include <QHBoxLayout>
+
 SwitchParamWidget::SwitchParamWidget(std::shared_ptr<AssetParameterModel> model, QModelIndex index, QWidget *parent)
     : AbstractParamWidget(std::move(model), index, parent)
 {
-    setupUi(this);
-
     // setup the comment
     QString comment = m_model->data(m_index, AssetParameterModel::CommentRole).toString();
     setToolTip(comment);
-    m_labelComment->setText(comment);
-    m_widgetComment->setHidden(true);
-
-    // setup the name
-    m_labelName->setText(m_model->data(m_index, Qt::DisplayRole).toString());
-    setMinimumHeight(m_labelName->sizeHint().height());
+    QHBoxLayout *lay = new QHBoxLayout(this);
+    lay->setContentsMargins(0, 0, 0, 0);
+    m_checkBox = new QCheckBox(this);
+    lay->addWidget(m_checkBox);
 
     // set check state
     slotRefresh();
 
-    // emit the signal of the base class when appropriate
+    // Q_EMIT the signal of the base class when appropriate
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(this->m_checkBox, &QCheckBox::checkStateChanged, this, [this](Qt::CheckState state) {
+#else
     connect(this->m_checkBox, &QCheckBox::stateChanged, this, [this](int state) {
-        emit valueChanged(m_index,
-                          (state == Qt::Checked ? m_model->data(m_index, AssetParameterModel::MaxRole).toString()
-                                                : m_model->data(m_index, AssetParameterModel::MinRole).toString()),
-                          true);
+#endif
+        Q_EMIT valueChanged(m_index,
+                            (state == Qt::Checked ? m_model->data(m_index, AssetParameterModel::MaxRole).toString()
+                                                  : m_model->data(m_index, AssetParameterModel::MinRole).toString()),
+                            true);
     });
 }
 
-void SwitchParamWidget::slotShowComment(bool show)
-{
-    if (!m_labelComment->text().isEmpty()) {
-        m_widgetComment->setVisible(show);
-    }
-}
-
 void SwitchParamWidget::slotRefresh()
 {
     const QSignalBlocker bk(m_checkBox);
