@@ -38,6 +38,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QJsonObject>
 #include <QMimeData>
 #include <QProgressDialog>
+#include <QStorageInfo>
 #include <QTemporaryFile>
 
 #include <mlt++/Mlt.h>
@@ -603,7 +604,7 @@ QStringList ProjectItemModel::getEnclosingFolderInfo(const QModelIndex &index) c
     return folderInfo;
 }
 
-void ProjectItemModel::clean()
+void ProjectItemModel::clean(bool quit)
 {
     QWriteLocker locker(&m_lock);
     closing = true;
@@ -611,8 +612,6 @@ void ProjectItemModel::clean()
     std::vector<std::shared_ptr<AbstractProjectItem>> toDelete;
     toDelete.reserve(size_t(rootItem->childCount()));
     for (int i = 0; i < rootItem->childCount(); ++i) {
-        qDebug() << "... FOUND CLIP: " << std::static_pointer_cast<AbstractProjectItem>(rootItem->child(i))->clipId() << " = "
-                 << std::static_pointer_cast<AbstractProjectItem>(rootItem->child(i))->name();
         toDelete.push_back(std::static_pointer_cast<AbstractProjectItem>(rootItem->child(i)));
     }
     Fun undo = []() { return true; };
@@ -620,12 +619,15 @@ void ProjectItemModel::clean()
     for (const auto &child : toDelete) {
         requestBinClipDeletion(child, undo, redo);
     }
+    toDelete.clear();
     Q_ASSERT(rootItem->childCount() == 0);
     closing = false;
-    m_nextId = 1;
-    m_uuid = QUuid::createUuid();
-    m_sequenceFolderId = -1;
-    buildPlaylist(m_uuid);
+    if (!quit) {
+        m_nextId = 1;
+        m_uuid = QUuid::createUuid();
+        m_sequenceFolderId = -1;
+        buildPlaylist(m_uuid);
+    }
     ThumbnailCache::get()->clearCache();
 }
 
@@ -1866,7 +1868,15 @@ void ProjectItemModel::updateWatcher(const std::shared_ptr<ProjectClip> &clipIte
         QFileInfo check_file(clipItem->clipUrl());
         // check if file exists and if yes: Is it really a file and no directory?
         if ((check_file.exists() && check_file.isFile()) || clipItem->clipStatus() == FileStatus::StatusMissing) {
+#ifdef Q_OS_WIN
+            // On Windows, monitoring a file on a non existing drive crashes.
+            QStorageInfo storage(check_file.absoluteDir());
+            if (storage.isValid() && storage.isReady()) {
+                m_fileWatcher->addFile(clipItem->clipId(), clipItem->clipUrl());
+            }
+#else
             m_fileWatcher->addFile(clipItem->clipId(), clipItem->clipUrl());
+#endif
         }
     }
 }
