@@ -70,6 +70,7 @@ class /*KDENLIVECORE_EXPORT*/ Core : public QObject
 
 public:
     friend class KdenliveDoc;
+    friend class ProjectManager;
     Core(const Core &) = delete;
     Core &operator=(const Core &) = delete;
     Core(Core &&) = delete;
@@ -249,7 +250,7 @@ public:
     bool isMediaCapturing() const;
     /** @brief True if we are currently displaying the record countdown */
     bool captureShowsCountDown() const;
-    MediaCapture *getAudioDevice();
+    std::shared_ptr<MediaCapture> getAudioDevice();
     /** @brief Returns configured folder for audio capture storage */
     QString getProjectCaptureFolderName();
     /** @brief Returns a timeline clip's bin id */
@@ -345,6 +346,10 @@ public:
     void highlightFileInExplorer(QList<QUrl> urls);
     /** @brief When a timeline operation changes the clip under the mouse cursor, inform the qml view */
     void updateHoverItem(const QUuid &uuid);
+    /** @brief Returns true if the asset has {audio, video} */
+    std::pair<bool, bool> assetHasAV(ObjectId id);
+    /** @brief Show an item's effect stack */
+    void showEffectStackFromId(ObjectId owner);
 
 private:
     explicit Core(LinuxPackageType packageType);
@@ -379,7 +384,7 @@ private:
     bool m_guiConstructed = false;
     /** @brief Check that the profile is valid (width is a multiple of 8 and height a multiple of 2 */
     void checkProfileValidity();
-    std::unique_ptr<MediaCapture> m_capture;
+    std::shared_ptr<MediaCapture> m_capture;
     QUrl m_mediaCaptureFile;
     void resetThumbProfile();
 
@@ -427,6 +432,8 @@ public Q_SLOTS:
     void startRecording(bool showCountdown = false);
     /** @brief Show or hide track head audio rec controls. */
     void monitorAudio(int tid, bool monitor);
+    /** @brief Open a documentation link, showing a warning box first */
+    void openDocumentationLink(const QUrl &link);
 
 Q_SIGNALS:
     void coreIsReady();
@@ -447,7 +454,7 @@ Q_SIGNALS:
     /** @brief Opening finished, close splash screen */
     void closeSplash();
     /** @brief Trigger an update of the speech models list */
-    void voskModelUpdate(const QStringList models);
+    void speechModelUpdate(SpeechToTextEngine::EngineType engine, const QStringList models);
     /** @brief Update current effect zone */
     void updateEffectZone(const QPoint p, bool withUndo);
     /** @brief The effect stask is about to be deleted, disconnect everything */
@@ -490,4 +497,6 @@ Q_SIGNALS:
     void requestShowBinEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize frameSize, bool showKeyframes);
     /** @brief Save guide categories in document properties */
     void saveGuideCategories();
+    /** @brief When creating a backup file, also save a thumbnail of current timeline */
+    void saveTimelinePreview(const QString &path);
 };
