@@ -14,10 +14,6 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include "klocalizedstring.h"
 #include <KCharsets>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTextCodec>
-#endif
-
 ImportSubtitle::ImportSubtitle(const QString &path, QWidget *parent)
     : QDialog(parent)
 {
@@ -29,11 +25,12 @@ ImportSubtitle::ImportSubtitle(const QString &path, QWidget *parent)
     QStringList listCodecs = KCharsets::charsets()->descriptiveEncodingNames();
     const QString filter = QStringLiteral("*.srt *.ass *.vtt *.sbv");
     subtitle_url->setNameFilter(filter);
-    codecs_list->addItems(listCodecs);
+    for (auto &l : listCodecs) {
+        codecs_list->addItem(l, KCharsets::charsets()->encodingForName(l));
+    }
     info_message->setVisible(false);
     // Set UTF-8 as default codec
-    QString utf8Desc = KCharsets::charsets()->descriptionForEncoding(QStringLiteral("UTF-8"));
-    int matchIndex = codecs_list->findText(utf8Desc);
+    int matchIndex = codecs_list->findData(QStringLiteral("UTF-8"));
     if (matchIndex > -1) {
         codecs_list->setCurrentIndex(matchIndex);
     }
@@ -52,21 +49,11 @@ ImportSubtitle::ImportSubtitle(const QString &path, QWidget *parent)
         }
         QByteArray codec = KCharsets::charsets()->encodingForName(codecs_list->currentText()).toUtf8();
         QTextStream stream(&srtFile);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QTextCodec *inputEncoding = QTextCodec::codecForName(codec);
-        if (inputEncoding) {
-            stream.setCodec(inputEncoding);
-        } else {
-            qWarning() << "No QTextCodec named" << codec;
-            stream.setCodec("UTF-8");
-        }
-#else
         std::optional<QStringConverter::Encoding> inputEncoding = QStringConverter::encodingForName(codec.data());
         if (inputEncoding) {
             stream.setEncoding(inputEncoding.value());
         }
         // else: UTF8 is the default
-#endif
         text_preview->clear();
         int maxLines = 30;
         QStringList textData;
