@@ -50,11 +50,7 @@ ProxyTest::ProxyTest(QWidget *parent)
         infoWidget->animatedShow();
         resultList->setCursor(Qt::BusyCursor);
         buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QtConcurrent::run(this, &ProxyTest::startTest);
-#else
         (void)QtConcurrent::run(&ProxyTest::startTest, this);
-#endif
     });
 }
 
@@ -112,7 +108,7 @@ void ProxyTest::startTest()
     QMapIterator<QString, QString> k(values);
     int proxyResize = pCore->currentDoc()->getDocumentProperty(QStringLiteral("proxyresize")).toInt();
     QElapsedTimer timer;
-    QTemporaryFile src(QDir::temp().absoluteFilePath(QString("XXXXXX.mov")));
+    QTemporaryFile src(QDir::temp().absoluteFilePath(QStringLiteral("XXXXXX.mov")));
     if (!src.open()) {
         // Something went wrong
         QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString, i18n("Cannot create temporary files")));
@@ -149,7 +145,7 @@ void ProxyTest::startTest()
             QString params = k.value().section(QLatin1Char(';'), 0, 0);
             QString extension = k.value().section(QLatin1Char(';'), 1, 1);
             // Testing vaapi support
-            QTemporaryFile tmp(QDir::temp().absoluteFilePath(QString("XXXXXX.%1").arg(extension)));
+            QTemporaryFile tmp(QDir::temp().absoluteFilePath(QStringLiteral("XXXXXX.%1").arg(extension)));
             if (!tmp.open()) {
                 // Something went wrong
                 QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString, i18n("Cannot create temporary files")));
@@ -160,7 +156,7 @@ void ProxyTest::startTest()
             if (params.contains(QStringLiteral("%frameSize"))) {
                 int w = proxyResize;
                 int h = w * 1080 / 1920;
-                params.replace(QStringLiteral("%frameSize"), QString("%1x%2").arg(w).arg(h));
+                params.replace(QStringLiteral("%frameSize"), QStringLiteral("%1x%2").arg(w).arg(h));
             }
             params.replace(QStringLiteral("%nvcodec"), QStringLiteral("h264_cuvid"));
             m_process.reset(new QProcess());
@@ -173,7 +169,7 @@ void ProxyTest::startTest()
                 parameters << QStringLiteral("-i") << src.fileName();
             }
             QStringList paramList = params.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-            for (const QString &s : qAsConst(paramList)) {
+            for (const QString &s : std::as_const(paramList)) {
                 QString t = s.simplified();
                 if (t != QLatin1String("-noautorotate")) {
                     parameters << t;
