@@ -38,8 +38,8 @@ private:
     int m_tid;
     int m_duration;
     std::unique_ptr<QTemporaryFile> m_tmpAudio;
-    std::unique_ptr<QTemporaryFile> m_tmpSrt;
-    QAction *m_voskConfig;
+    QString m_tmpSrtPath;
+    QAction *m_speechConfig;
     QAction *m_logAction;
     QString m_errorLog;
     SpeechToText *m_stt;
@@ -47,9 +47,9 @@ private:
 
 private Q_SLOTS:
     void slotProcessSpeech();
-    void slotProcessSpeechStatus(QProcess::ExitStatus status, const QString &srtFile);
+    void slotProcessSpeechStatus(int exitCode, QProcess::ExitStatus status);
     void slotProcessProgress();
     void slotProcessWhisperProgress();
-    void updateVoskModels(const QStringList models);
+    void buildSpeechModelsList(SpeechToTextEngine::EngineType engine, const QStringList models);
     void checkDeps();
 };
