@@ -66,7 +66,7 @@ void VideoTextEdit::cleanup()
     cutZones.clear();
     m_hoveredBlock = -1;
     clear();
-    document()->setDefaultStyleSheet(QString("a {text-decoration:none;color:%1}").arg(palette().text().color().name()));
+    document()->setDefaultStyleSheet(QStringLiteral("a {text-decoration:none;color:%1}").arg(palette().text().color().name()));
     setCurrentFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 }
 
@@ -616,6 +616,8 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
 
     // Settings menu
     QMenu *menu = new QMenu(this);
+    m_modelsMenu = new QMenu(i18n("Speech Model"), this);
+    menu->addMenu(m_modelsMenu);
     m_translateAction = new QAction(i18n("Translate to English"), this);
     m_translateAction->setCheckable(true);
     menu->addAction(m_translateAction);
@@ -630,8 +632,11 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
         m_translateAction->setEnabled(KdenliveSettings::speechEngine() == QLatin1String("whisper"));
     });
 
-    m_voskConfig = new QAction(i18n("Configure"), this);
-    connect(m_voskConfig, &QAction::triggered, []() { pCore->window()->slotShowPreferencePage(Kdenlive::PageSpeech); });
+    m_speechConfig = new QAction(i18n("Configure"), this);
+    connect(m_speechConfig, &QAction::triggered, this, [this]() {
+        info_message->animatedHide();
+        pCore->window()->slotShowPreferencePage(Kdenlive::PageSpeech);
+    });
 
     // Visual text editor
     auto *l = new QVBoxLayout;
@@ -659,7 +664,9 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
     insertMenu->addAction(saveAsPlaylist);
     button_insert->setMenu(insertMenu);
     button_insert->setDefaultAction(createSequence);
-    button_insert->setToolTip(i18n("Create new sequence with text edit "));
+    button_insert->setToolTip(i18n("Create new sequence with text edit"));
+    button_search->setToolTip(i18n("Search in text"));
+    language_box->setToolTip(i18n("Language"));
 
     connect(createSequence, &QAction::triggered, this, &TextBasedEdit::createSequence);
     connect(insertSelection, &QAction::triggered, this, &TextBasedEdit::insertToTimeline);
@@ -673,7 +680,7 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
         insertSelection->setEnabled(hasSelection);
     });
 
-    button_start->setEnabled(false);
+    enableEditActions(false, false);
     connect(button_start, &QPushButton::clicked, this, &TextBasedEdit::startRecognition);
     frame_progress->setVisible(false);
     connect(button_abort, &QToolButton::clicked, this, [this]() {
@@ -683,33 +690,24 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
             m_tCodeJob->kill();
         }
     });
-    language_box->setToolTip(i18n("Speech model"));
-    speech_language->setToolTip(i18n("Speech language"));
-    connect(pCore.get(), &Core::voskModelUpdate, this, [&](const QStringList &models) {
-        if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
+    connect(pCore.get(), &Core::speechModelUpdate, this, [&](SpeechToTextEngine::EngineType engine, const QStringList &models) {
+        if (engine == SpeechToTextEngine::EngineWhisper) {
+            if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
+                buildWhisperModelsList(models);
+            }
             return;
         }
-        language_box->clear();
-        language_box->addItems(models);
-
-        if (models.isEmpty()) {
-            showMessage(i18n("Please install speech recognition models"), KMessageWidget::Information, m_voskConfig);
-        } else {
-            if (!KdenliveSettings::vosk_text_model().isEmpty() && models.contains(KdenliveSettings::vosk_text_model())) {
-                int ix = language_box->findText(KdenliveSettings::vosk_text_model());
-                if (ix > -1) {
-                    language_box->setCurrentIndex(ix);
-                }
-            }
+        if (engine == SpeechToTextEngine::EngineVosk && KdenliveSettings::speechEngine() == QLatin1String("vosk")) {
+            buildVoskModelsList(models);
         }
     });
-    connect(language_box, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, [this]() {
+    connect(m_modelsMenu, &QMenu::triggered, this, [this](QAction *a) {
         if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
-            const QString modelName = language_box->currentData().toString();
-            speech_language->setEnabled(!modelName.endsWith(QLatin1String(".en")));
+            const QString modelName = a->data().toString();
+            language_box->setEnabled(!modelName.endsWith(QLatin1String(".en")));
             KdenliveSettings::setWhisperModel(modelName);
         } else {
-            KdenliveSettings::setVosk_text_model(language_box->currentText());
+            KdenliveSettings::setVosk_text_model(a->data().toString());
         }
     });
     info_message->hide();
@@ -719,7 +717,11 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
     connect(m_logAction, &QAction::triggered, this, [this]() { KMessageBox::error(this, m_errorString, i18n("Detailed log")); });
 
     speech_zone->setChecked(KdenliveSettings::speech_zone());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+    connect(speech_zone, &QCheckBox::checkStateChanged, [](Qt::CheckState state) { KdenliveSettings::setSpeech_zone(state == Qt::Checked); });
+#else
     connect(speech_zone, &QCheckBox::stateChanged, [](int state) { KdenliveSettings::setSpeech_zone(state == Qt::Checked); });
+#endif
     button_delete->setDefaultAction(m_visualEditor->deleteAction);
     button_delete->setToolTip(i18n("Delete selected text"));
     connect(m_visualEditor->deleteAction, &QAction::triggered, this, &TextBasedEdit::deleteItem);
@@ -729,19 +731,16 @@ TextBasedEdit::TextBasedEdit(QWidget *parent)
     connect(m_visualEditor->bookmarkAction, &QAction::triggered, this, &TextBasedEdit::addBookmark);
 
     // Zoom
-    QAction *zoomIn = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18n("Zoom In"), this);
+    QAction *zoomIn = new QAction(QIcon::fromTheme(QStringLiteral("format-font-size-more")), i18n("Increase Font Size"), this);
     connect(zoomIn, &QAction::triggered, this, &TextBasedEdit::slotZoomIn);
-    QAction *zoomOut = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18n("Zoom Out"), this);
+    button_font_more->setDefaultAction(zoomIn);
+    QAction *zoomOut = new QAction(QIcon::fromTheme(QStringLiteral("format-font-size-less")), i18n("Decrease Font Size"), this);
     connect(zoomOut, &QAction::triggered, this, &TextBasedEdit::slotZoomOut);
-    QAction *removeSilence = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove non speech zones"), this);
+    button_font_less->setDefaultAction(zoomOut);
+
+    QAction *removeSilence = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete-remove")), i18n("Remove non speech zones"), this);
     connect(removeSilence, &QAction::triggered, m_visualEditor, &VideoTextEdit::slotRemoveSilence);
-    // Build menu
-    QMenu *extraMenu = new QMenu(this);
-    extraMenu->addAction(zoomIn);
-    extraMenu->addAction(zoomOut);
-    extraMenu->addSeparator();
-    extraMenu->addAction(removeSilence);
-    subMenu->setMenu(extraMenu);
+    button_remove_silence->setDefaultAction(removeSilence);
 
     // Message Timer
     m_hideTimer.setSingleShot(true);
@@ -850,37 +849,101 @@ void TextBasedEdit::updateEngine()
 {
     delete m_stt;
     if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
-        m_stt = new SpeechToText(SpeechToText::EngineType::EngineWhisper, this);
+        m_stt = new SpeechToTextWhisper(this);
+        m_modelsMenu->clear();
+        const QStringList whisperModels = m_stt->getInstalledModels();
+        buildWhisperModelsList(whisperModels);
         language_box->clear();
-        QList<std::pair<QString, QString>> whisperModels = m_stt->whisperModels();
-        for (auto &w : whisperModels) {
-            language_box->addItem(w.first, w.second);
+        QMap<QString, QString> languages = m_stt->speechLanguages();
+        QMapIterator<QString, QString> j(languages);
+        while (j.hasNext()) {
+            j.next();
+            language_box->addItem(j.key(), j.value());
         }
-        int ix = language_box->findData(KdenliveSettings::whisperModel());
+        int ix = language_box->findData(KdenliveSettings::whisperLanguage());
         if (ix > -1) {
             language_box->setCurrentIndex(ix);
         }
-        if (speech_language->count() == 0) {
-            // Fill whisper languages
-            QMap<QString, QString> languages = m_stt->whisperLanguages();
-            QMapIterator<QString, QString> j(languages);
-            while (j.hasNext()) {
-                j.next();
-                speech_language->addItem(j.key(), j.value());
-            }
-            int ix = speech_language->findData(KdenliveSettings::whisperLanguage());
-            if (ix > -1) {
-                speech_language->setCurrentIndex(ix);
-            }
-        }
-        speech_language->setEnabled(!KdenliveSettings::whisperModel().endsWith(QLatin1String(".en")));
-        speech_language->setVisible(true);
+        language_box->setEnabled(!KdenliveSettings::whisperModel().endsWith(QLatin1String(".en")));
+        language_box->setVisible(true);
     } else {
         // VOSK
-        speech_language->setVisible(false);
-        m_stt = new SpeechToText(SpeechToText::EngineType::EngineVosk, this);
-        language_box->clear();
-        m_stt->parseVoskDictionaries();
+        language_box->setVisible(false);
+        m_stt = new SpeechToTextVosk(this);
+        const QStringList voskModels = m_stt->getInstalledModels();
+        buildVoskModelsList(voskModels);
+    }
+}
+
+void TextBasedEdit::buildVoskModelsList(const QStringList models)
+{
+    m_modelsMenu->clear();
+    delete m_modelsGroup;
+    m_modelsGroup = new QActionGroup(this);
+    if (models.isEmpty()) {
+        showMessage(i18n("Please install speech recognition models"), KMessageWidget::Information, m_speechConfig);
+        button_start->setEnabled(false);
+        return;
+    }
+    button_start->setEnabled(true);
+    QAction *a = nullptr;
+    for (auto &m : models) {
+        a = m_modelsMenu->addAction(m);
+        a->setData(m);
+        a->setCheckable(true);
+        m_modelsGroup->addAction(a);
+    }
+
+    bool found = false;
+    QList<QAction *> acts = m_modelsMenu->actions();
+    if (!KdenliveSettings::vosk_text_model().isEmpty() && models.contains(KdenliveSettings::vosk_text_model())) {
+        for (auto &a : acts) {
+            if (a->data().toString() == KdenliveSettings::vosk_text_model()) {
+                a->setChecked(true);
+                found = true;
+                break;
+            }
+        }
+    }
+    if (!found && !acts.isEmpty()) {
+        QAction *a = acts.first();
+        a->setChecked(true);
+    }
+}
+
+void TextBasedEdit::buildWhisperModelsList(const QStringList whisperModels)
+{
+    m_modelsMenu->clear();
+    delete m_modelsGroup;
+    m_modelsGroup = new QActionGroup(this);
+    if (whisperModels.isEmpty()) {
+        button_start->setEnabled(false);
+        showMessage(i18n("Please install speech recognition models"), KMessageWidget::Information, m_speechConfig);
+        return;
+    }
+    button_start->setEnabled(true);
+    QAction *a = nullptr;
+    bool found = false;
+    for (auto &w : whisperModels) {
+        if (w.isEmpty()) {
+            continue;
+        }
+        QString modelName = w;
+        modelName[0] = w.at(0).toUpper();
+        a = m_modelsMenu->addAction(modelName);
+        a->setCheckable(true);
+        a->setData(w);
+        m_modelsGroup->addAction(a);
+        if (w == KdenliveSettings::whisperModel()) {
+            a->setChecked(true);
+            found = true;
+        }
+    }
+    if (!found) {
+        QList<QAction *> acts = m_modelsMenu->actions();
+        if (!acts.isEmpty()) {
+            acts.first()->setChecked(true);
+        }
     }
 }
 
@@ -928,11 +991,13 @@ void TextBasedEdit::startRecognition()
     if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
         // Whisper engine
         if (!m_stt->checkSetup() || !m_stt->missingDependencies({QStringLiteral("openai-whisper")}).isEmpty()) {
-            showMessage(i18n("Please configure speech to text."), KMessageWidget::Warning, m_voskConfig);
+            showMessage(i18n("Please configure speech to text."), KMessageWidget::Warning, m_speechConfig);
             return;
         }
-        modelName = language_box->currentData().toString();
-        language = speech_language->isEnabled() ? speech_language->currentData().toString().simplified() : QString();
+        if (m_modelsGroup->checkedAction()) {
+            modelName = m_modelsGroup->checkedAction()->data().toString();
+        }
+        language = language_box->isEnabled() ? language_box->currentData().toString().simplified() : QString();
         if (!language.isEmpty()) {
             language.prepend(QStringLiteral("language="));
         }
@@ -942,16 +1007,18 @@ void TextBasedEdit::startRecognition()
     } else {
         // VOSK engine
         if (!m_stt->checkSetup() || !m_stt->missingDependencies({QStringLiteral("vosk")}).isEmpty()) {
-            showMessage(i18n("Please configure speech to text."), KMessageWidget::Warning, m_voskConfig);
+            showMessage(i18n("Please configure speech to text."), KMessageWidget::Warning, m_speechConfig);
             return;
         }
         // Start python script
-        modelName = language_box->currentText();
+        if (m_modelsGroup->checkedAction()) {
+            modelName = m_modelsGroup->checkedAction()->data().toString();
+        }
         if (modelName.isEmpty()) {
-            showMessage(i18n("Please install a language model."), KMessageWidget::Warning, m_voskConfig);
+            showMessage(i18n("Please install a language model."), KMessageWidget::Warning, m_speechConfig);
             return;
         }
-        modelDirectory = m_stt->voskModelPath();
+        modelDirectory = m_stt->modelFolder();
     }
     m_binId = pCore->getMonitor(Kdenlive::ClipMonitor)->activeClipId();
     std::shared_ptr<AbstractProjectItem> clip = pCore->projectItemModel()->getItemByBinId(m_binId);
@@ -1074,7 +1141,7 @@ void TextBasedEdit::startRecognition()
             speech_progress->setValue(percent);
         });
         m_tCodeJob->start(KdenliveSettings::meltpath(),
-                          {QStringLiteral("-progress"), m_sourceUrl, QStringLiteral("-consumer"), QString("avformat:%1").arg(m_playlistWav.fileName()),
+                          {QStringLiteral("-progress"), m_sourceUrl, QStringLiteral("-consumer"), QStringLiteral("avformat:%1").arg(m_playlistWav.fileName()),
                            QStringLiteral("vn=1"), QStringLiteral("ar=16000")});
         speech_progress->setValue(0);
         frame_progress->setVisible(true);
@@ -1087,7 +1154,7 @@ void TextBasedEdit::startRecognition()
         button_insert->setEnabled(false);
         if (KdenliveSettings::speechEngine() == QLatin1String("whisper")) {
             // Whisper
-            qDebug() << "=== STARTING Whisper reco: " << m_stt->speechScript() << " / " << language_box->currentData() << " / "
+            qDebug() << "=== STARTING Whisper reco: " << m_stt->speechScript() << " / " << language_box->currentData().toString() << " / "
                      << KdenliveSettings::whisperDevice() << " / "
                      << (KdenliveSettings::whisperTranslate() ? QStringLiteral("translate") : QStringLiteral("transcribe")) << " / " << m_sourceUrl
                      << ", START: " << m_clipOffset << ", DUR: " << endPos << " / " << language;
@@ -1126,12 +1193,14 @@ void TextBasedEdit::slotProcessSpeechStatus(int, QProcess::ExitStatus status)
     if (status == QProcess::CrashExit) {
         showMessage(i18n("Speech recognition aborted."), KMessageWidget::Warning, m_errorString.isEmpty() ? nullptr : m_logAction);
     } else if (m_visualEditor->toPlainText().isEmpty()) {
+        enableEditActions(false);
         if (m_errorString.contains(QStringLiteral("ModuleNotFoundError"))) {
-            showMessage(i18n("Error, please check the speech to text configuration."), KMessageWidget::Warning, m_voskConfig);
+            showMessage(i18n("Error, please check the speech to text configuration."), KMessageWidget::Warning, m_speechConfig);
         } else {
             showMessage(i18n("No speech detected."), KMessageWidget::Information, m_errorString.isEmpty() ? nullptr : m_logAction);
         }
     } else {
+        enableEditActions(true);
         // Last empty object - no speech detected
         if (KdenliveSettings::speechEngine() != QLatin1String("whisper")) {
             // VOSK
@@ -1140,7 +1209,7 @@ void TextBasedEdit::slotProcessSpeechStatus(int, QProcess::ExitStatus status)
                 m_visualEditor->moveCursor(QTextCursor::End);
                 QTextCursor cursor = m_visualEditor->textCursor();
                 QTextCharFormat fmt = cursor.charFormat();
-                fmt.setAnchorHref(QString("%1#%2:%3").arg(m_binId).arg(silenceStart.seconds()).arg(GenTime(m_clipDuration + m_clipOffset).seconds()));
+                fmt.setAnchorHref(QStringLiteral("%1#%2:%3").arg(m_binId).arg(silenceStart.seconds()).arg(GenTime(m_clipDuration + m_clipOffset).seconds()));
                 fmt.setAnchor(true);
                 cursor.insertText(i18n("No speech"), fmt);
                 m_visualEditor->textCursor().insertBlock(cursor.blockFormat());
@@ -1149,7 +1218,6 @@ void TextBasedEdit::slotProcessSpeechStatus(int, QProcess::ExitStatus status)
             }
         }
 
-        button_insert->setEnabled(true);
         showMessage(i18n("Speech recognition finished."), KMessageWidget::Positive);
         // Store speech analysis in clip properties
         std::shared_ptr<AbstractProjectItem> clip = pCore->projectItemModel()->getItemByBinId(m_binId);
@@ -1208,7 +1276,7 @@ void TextBasedEdit::slotProcessWhisperSpeech()
         // Insert space
         GenTime silenceStart(m_lastPosition, pCore->getCurrentFps());
         m_visualEditor->moveCursor(QTextCursor::End);
-        fmt.setAnchorHref(QString("%1#%2:%3")
+        fmt.setAnchorHref(QStringLiteral("%1#%2:%3")
                               .arg(m_binId)
                               .arg(silenceStart.seconds())
                               .arg(GenTime(sentenceStart.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds()));
@@ -1232,7 +1300,7 @@ void TextBasedEdit::slotProcessWhisperSpeech()
             if (nextSentence.frames(pCore->getCurrentFps()) > lastSentence.frames(pCore->getCurrentFps()) + 1) {
                 // Insert space
                 m_visualEditor->moveCursor(QTextCursor::End);
-                fmt.setAnchorHref(QString("%1#%2:%3")
+                fmt.setAnchorHref(QStringLiteral("%1#%2:%3")
                                       .arg(m_binId)
                                       .arg(lastSentence.seconds())
                                       .arg(GenTime(nextSentence.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds()));
@@ -1247,7 +1315,7 @@ void TextBasedEdit::slotProcessWhisperSpeech()
             continue;
         }
         fmt.setAnchor(true);
-        fmt.setAnchorHref(QString("%1#%2:%3").arg(m_binId).arg(wordZone.first).arg(wordZone.second));
+        fmt.setAnchorHref(QStringLiteral("%1#%2:%3").arg(m_binId).arg(wordZone.first).arg(wordZone.second));
         cursor.insertText(text, fmt);
         fmt.setAnchor(false);
         cursor.insertText(QStringLiteral(" "), fmt);
@@ -1289,7 +1357,7 @@ void TextBasedEdit::slotProcessSpeech()
                         // Insert space
                         GenTime silenceStart(m_lastPosition, pCore->getCurrentFps());
                         m_visualEditor->moveCursor(QTextCursor::End);
-                        fmt.setAnchorHref(QString("%1#%2:%3")
+                        fmt.setAnchorHref(QStringLiteral("%1#%2:%3")
                                               .arg(m_binId)
                                               .arg(silenceStart.seconds())
                                               .arg(GenTime(startPos.frames(pCore->getCurrentFps()) - 1, pCore->getCurrentFps()).seconds()));
@@ -1313,7 +1381,7 @@ void TextBasedEdit::slotProcessSpeech()
                 for (const QJsonValue &v : obj2) {
                     textFound = true;
                     fmt.setAnchor(true);
-                    fmt.setAnchorHref(QString("%1#%2:%3")
+                    fmt.setAnchorHref(QStringLiteral("%1#%2:%3")
                                           .arg(m_binId)
                                           .arg(v.toObject().value("start").toDouble() + m_clipOffset)
                                           .arg(v.toObject().value("end").toDouble() + m_clipOffset));
@@ -1435,16 +1503,16 @@ void TextBasedEdit::previewPlaylist(bool createNew)
     QMap<QString, QString> properties;
     properties.insert(QStringLiteral("kdenlive:baseid"), m_binId);
     QStringList playZones;
-    for (const auto &p : qAsConst(zones)) {
-        playZones << QString("%1:%2").arg(p.x()).arg(p.y());
+    for (const auto &p : std::as_const(zones)) {
+        playZones << QStringLiteral("%1:%2").arg(p.x()).arg(p.y());
     }
     properties.insert(QStringLiteral("kdenlive:cutzones"), playZones.join(QLatin1Char(';')));
     if (createNew) {
         int ix = 1;
-        m_playlist = QString("%1-cut%2.kdenlive").arg(sourcePath).arg(ix);
+        m_playlist = QStringLiteral("%1-cut%2.kdenlive").arg(sourcePath).arg(ix);
         while (QFile::exists(m_playlist)) {
             ix++;
-            m_playlist = QString("%1-cut%2.kdenlive").arg(sourcePath).arg(ix);
+            m_playlist = QStringLiteral("%1-cut%2.kdenlive").arg(sourcePath).arg(ix);
         }
         QUrl url = KUrlRequesterDialog::getUrl(QUrl::fromLocalFile(m_playlist), this, i18n("Enter new playlist path"));
         if (url.isEmpty()) {
@@ -1496,7 +1564,7 @@ void TextBasedEdit::createSequence()
         // Aborting
         return;
     }
-    for (const auto &p : qAsConst(zones)) {
+    for (const auto &p : std::as_const(zones)) {
         if (p.y() > p.x()) {
             pCore->window()->getCurrentTimeline()->controller()->insertZone(m_binId, p, false, undo, redo);
         }
@@ -1557,7 +1625,7 @@ void TextBasedEdit::openClip(std::shared_ptr<ProjectClip> clip)
                 clipNameLabel->setText(refClip->clipName());
             }
             QStringList zones = clip->getProducerProperty("kdenlive:cutzones").split(QLatin1Char(';'));
-            for (const QString &z : qAsConst(zones)) {
+            for (const QString &z : std::as_const(zones)) {
                 cutZones << QPoint(z.section(QLatin1Char(':'), 0, 0).toInt(), z.section(QLatin1Char(':'), 1, 1).toInt());
             }
         } else {
@@ -1567,8 +1635,7 @@ void TextBasedEdit::openClip(std::shared_ptr<ProjectClip> clip)
         }
         if (speech.isEmpty()) {
             // Nothing else to do
-            button_insert->setEnabled(false);
-            button_start->setEnabled(true);
+            enableEditActions(false, true);
             return;
         }
         m_visualEditor->insertHtml(speech);
@@ -1576,10 +1643,9 @@ void TextBasedEdit::openClip(std::shared_ptr<ProjectClip> clip)
             m_visualEditor->processCutZones(cutZones);
         }
         m_visualEditor->rebuildZones();
-        button_insert->setEnabled(true);
-        button_start->setEnabled(true);
+        enableEditActions(true);
     } else {
-        button_start->setEnabled(false);
+        enableEditActions(false, false);
         clipNameLabel->clear();
         m_visualEditor->cleanup();
     }
@@ -1615,3 +1681,12 @@ void TextBasedEdit::addBookmark()
         qDebug() << "==== NO CLIP FOR " << m_binId;
     }
 }
+
+void TextBasedEdit::enableEditActions(bool enable, bool enableStart)
+{
+    button_insert->setEnabled(enable);
+    button_delete->setEnabled(enable);
+    button_remove_silence->setEnabled(enable);
+    button_search->setEnabled(enable);
+    button_start->setEnabled(enableStart);
+}
