@@ -38,7 +38,7 @@ EffectsRepository::EffectsRepository()
     if (!invalidEffect.isEmpty()) {
         pCore->displayMessage(i18n("Some of your favorite effects are invalid and were removed: %1", invalidEffect.join(QLatin1Char(','))), ErrorMessage);
         QStringList newFavorites = KdenliveSettings::favorite_effects();
-        for (const QString &effect : qAsConst(invalidEffect)) {
+        for (const QString &effect : std::as_const(invalidEffect)) {
             newFavorites.removeAll(effect);
         }
         KdenliveSettings::setFavorite_effects(newFavorites);
@@ -264,7 +264,7 @@ QString EffectsRepository::getCustomPath(const QString &id)
     QString customAssetDir = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("effects"), QStandardPaths::LocateDirectory);
     QPair<QStringList, QStringList> results;
     QDir current_dir(customAssetDir);
-    return current_dir.absoluteFilePath(QString("%1.xml").arg(id));
+    return current_dir.absoluteFilePath(QStringLiteral("%1.xml").arg(id));
 }
 
 QPair<QString, QString> EffectsRepository::reloadCustom(const QString &path)
@@ -302,7 +302,7 @@ QPair<QStringList, QStringList> EffectsRepository::fixDeprecatedEffects()
     filter << QStringLiteral("*.xml");
     QStringList fileList = current_dir.entryList(filter, QDir::Files);
     QStringList failed;
-    for (const auto &file : qAsConst(fileList)) {
+    for (const auto &file : std::as_const(fileList)) {
         QString path = current_dir.absoluteFilePath(file);
         QPair<QString, QString> fixResult = fixCustomAssetFile(path);
         if (!fixResult.first.isEmpty()) {
@@ -383,12 +383,12 @@ QPair<QString, QString> EffectsRepository::fixCustomAssetFile(const QString &pat
                         if (currentValue.contains(QLatin1Char('='))) {
                             QStringList valueStr = currentValue.split(QLatin1Char(';'));
                             QStringList resultStr;
-                            for (const QString &val : qAsConst(valueStr)) {
+                            for (const QString &val : std::as_const(valueStr)) {
                                 if (val.contains(QLatin1Char('='))) {
                                     QString frame = val.section(QLatin1Char('='), 0, 0);
                                     QString frameVal = val.section(QLatin1Char('='), 1);
                                     double v = frameVal.toDouble() / factor;
-                                    resultStr << QString("%1=%2").arg(frame).arg(v);
+                                    resultStr << QStringLiteral("%1=%2").arg(frame).arg(v);
                                 } else {
                                     double v = val.toDouble() / factor;
                                     resultStr << QString::number(v);
@@ -414,9 +414,6 @@ QPair<QString, QString> EffectsRepository::fixCustomAssetFile(const QString &pat
         }
         if (file.open(QFile::WriteOnly | QFile::Truncate)) {
             QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            out.setCodec("UTF-8");
-#endif
             out << doc.toString();
         } else {
             KMessageBox::error(QApplication::activeWindow(), i18n("Cannot write to file %1", file.fileName()));
