@@ -112,7 +112,7 @@ void SpeedTask::start(QObject *object, bool force)
             QDir dir(fileUrl.url().toLocalFile());
             binClip = pCore->projectItemModel()->getClipByBinID(binId.section(QLatin1Char('/'), 0, 0));
             mltfile = QFileInfo(binClip->url()).fileName().section(QLatin1Char('.'), 0, -2);
-            mltfile.append(QString("-%1.mlt").arg(QString::number(int(speed))));
+            mltfile.append(QStringLiteral("-%1.mlt").arg(QString::number(int(speed))));
             mltfile = dir.absoluteFilePath(mltfile);
         }
         // Filter several clips, destination points to a folder
@@ -141,14 +141,14 @@ void SpeedTask::start(QObject *object, bool force)
                 qDebug() << "=== INVALID SUBCLIP DATA: " << id;
                 continue;
             }
-            owner = ObjectId(ObjectType::BinClip, binData.first().toInt(), QUuid());
+            owner = ObjectId(KdenliveObjectType::BinClip, binData.first().toInt(), QUuid());
             binClip = pCore->projectItemModel()->getClipByBinID(binData.first());
             if (binClip) {
                 task = new SpeedTask(owner, destinations.at(id), binData.at(1).toInt(), binData.at(2).toInt(), filterParams, binClip.get());
             }
         } else {
             // Process full clip
-            owner = ObjectId(ObjectType::BinClip, id.toInt(), QUuid());
+            owner = ObjectId(KdenliveObjectType::BinClip, id.toInt(), QUuid());
             binClip = pCore->projectItemModel()->getClipByBinID(id);
             if (binClip) {
                 task = new SpeedTask(owner, destinations.at(id), -1, -1, filterParams, binClip.get());
@@ -185,12 +185,12 @@ void SpeedTask::run()
                                       Q_ARG(int, int(KMessageWidget::Warning)));
             return;
         }
-        producerArgs << QString("timewarp:%1:%2").arg(m_speed).arg(url);
+        producerArgs << QStringLiteral("timewarp:%1:%2").arg(m_speed).arg(url);
         if (m_inPoint > -1) {
-            producerArgs << QString("in=%1").arg(m_inPoint);
+            producerArgs << QStringLiteral("in=%1").arg(m_inPoint);
         }
         if (m_outPoint > -1) {
-            producerArgs << QString("out=%1").arg(m_outPoint);
+            producerArgs << QStringLiteral("out=%1").arg(m_outPoint);
         }
     } else {
         QMetaObject::invokeMethod(pCore.get(), "displayBinMessage", Qt::QueuedConnection, Q_ARG(QString, i18n("No producer for this clip.")),
@@ -199,9 +199,9 @@ void SpeedTask::run()
         // Filter applied on a track of master producer, leave config to source job
         // We are on master or track, configure producer accordingly
         // TODO
-        /*if (m_owner.type == ObjectType::Master) {
+        /*if (m_owner.type == KdenliveObjectType::Master) {
             producer = pCore->getMasterProducerInstance();
-        } else if (m_owner.type == ObjectType::TimelineTrack) {
+        } else if (m_owner.type == KdenliveObjectType::TimelineTrack) {
             producer = pCore->getTrackProducerInstance(m_owner.second);
         }
         if ((producer == nullptr) || !producer->is_valid()) {
@@ -214,20 +214,16 @@ void SpeedTask::run()
     // Process filter params
     for (const auto &it : m_filterParams) {
         qDebug() << ". . ." << it.first << " = " << it.second;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if (it.second.type() == QVariant::Double) {
-#else
         if (it.second.typeId() == QMetaType::Double) {
-#endif
-            producerArgs << QString("%1=%2").arg(it.first, QString::number(it.second.toDouble()));
+            producerArgs << QStringLiteral("%1=%2").arg(it.first, QString::number(it.second.toDouble()));
         } else {
-            producerArgs << QString("%1=%2").arg(it.first, it.second.toString());
+            producerArgs << QStringLiteral("%1=%2").arg(it.first, it.second.toString());
         }
     }
 
     // Start the MLT Process
     QProcess filterProcess;
-    producerArgs << QStringLiteral("-consumer") << QString("xml:%1").arg(m_destination) << QStringLiteral("terminate_on_pause=1");
+    producerArgs << QStringLiteral("-consumer") << QStringLiteral("xml:%1").arg(m_destination) << QStringLiteral("terminate_on_pause=1");
     m_jobProcess.reset(new QProcess);
     QMetaObject::invokeMethod(m_object, "updateJobProgress");
     QObject::connect(this, &AbstractTask::jobCanceled, m_jobProcess.get(), &QProcess::kill, Qt::DirectConnection);
