@@ -68,15 +68,12 @@ void TranscodeTask::run()
     QString source;
     QTemporaryFile src;
     if (type == ClipType::Text || type == ClipType::Timeline) {
-        src.setFileTemplate(QDir::temp().absoluteFilePath(QString("XXXXXX.mlt")));
+        src.setFileTemplate(QDir::temp().absoluteFilePath(QStringLiteral("XXXXXX.mlt")));
         if (src.open()) {
             source = src.fileName();
             QDomDocument doc;
             binClip->getProducerXML(doc, false, true);
             QTextStream out(&src);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            out.setCodec("UTF-8");
-#endif
             out << doc.toString();
             src.close();
         }
@@ -125,18 +122,18 @@ void TranscodeTask::run()
         // change FFmpeg params to MLT format
         m_isFfmpegJob = false;
         // insert transcoded filename
-        m_transcodeParams.replace(QStringLiteral("%1"), QString("-consumer %1"));
+        m_transcodeParams.replace(QStringLiteral("%1"), QStringLiteral("-consumer %1"));
         // Convert param style
         QStringList params = m_transcodeParams.split(QLatin1Char('-'), Qt::SkipEmptyParts);
         QStringList mltParameters;
-        for (const QString &s : qAsConst(params)) {
+        for (const QString &s : std::as_const(params)) {
             QString t = s.simplified();
             if (t.count(QLatin1Char(' ')) == 0) {
                 t.append(QLatin1String("=1"));
             } else {
                 if (t.contains(QLatin1String("%1"))) {
                     // file name
-                    mltParameters.prepend(t.section(QLatin1Char(' '), 1).replace(QLatin1String("%1"), QString("avformat:%1").arg(destUrl)));
+                    mltParameters.prepend(t.section(QLatin1Char(' '), 1).replace(QLatin1String("%1"), QStringLiteral("avformat:%1").arg(destUrl)));
                     mltParameters.prepend(QStringLiteral("-consumer"));
                     continue;
                 }
@@ -162,8 +159,8 @@ void TranscodeTask::run()
         // Ask for progress reporting
         mltParameters << QStringLiteral("progress=1");
         if (m_outPoint > 0) {
-            mltParameters.prepend(QString("out=%1").arg(m_outPoint));
-            mltParameters.prepend(QString("in=%1").arg(m_inPoint));
+            mltParameters.prepend(QStringLiteral("out=%1").arg(m_outPoint));
+            mltParameters.prepend(QStringLiteral("in=%1").arg(m_inPoint));
         }
         mltParameters.prepend(source);
         m_jobProcess.reset(new QProcess);
@@ -205,7 +202,7 @@ void TranscodeTask::run()
             parameters << QStringLiteral("-map") << QStringLiteral("0");
         }
         QStringList params = m_transcodeParams.split(QLatin1Char(' '));
-        for (const QString &s : qAsConst(params)) {
+        for (const QString &s : std::as_const(params)) {
             QString t = s.simplified();
             if (t.startsWith(QLatin1String("%1"))) {
                 parameters << t.replace(QLatin1String("%1"), destUrl);
@@ -216,7 +213,7 @@ void TranscodeTask::run()
         qDebug() << "/// FULL TRANSCODE PARAMS:\n" << parameters << "\n------";
         m_jobProcess.reset(new QProcess);
         QObject::connect(this, &TranscodeTask::jobCanceled, m_jobProcess.get(), &QProcess::kill, Qt::DirectConnection);
-        QObject::connect(m_jobProcess.get(), &QProcess::readyReadStandardError, this, &TranscodeTask::processLogInfo);
+        QObject::connect(m_jobProcess.get(), &QProcess::readyReadStandardError, this, &TranscodeTask::processLogInfo, Qt::DirectConnection);
         m_jobProcess->start(KdenliveSettings::ffmpegpath(), parameters, QIODevice::ReadOnly);
         AbstractTask::setPreferredPriority(m_jobProcess->processId());
         m_jobProcess->waitForFinished(-1);
@@ -280,7 +277,7 @@ void TranscodeTask::processLogInfo()
         // Parse FFmpeg output
         if (m_jobDuration == 0) {
             if (buffer.contains(QLatin1String("Duration:"))) {
-                QString data = buffer.section(QStringLiteral("Duration:"), 1, 1).section(QLatin1Char(','), 0, 0).simplified();
+                const QString data = buffer.section(QStringLiteral("Duration:"), 1, 1).section(QLatin1Char(','), 0, 0).simplified();
                 if (!data.isEmpty()) {
                     QStringList numbers = data.split(QLatin1Char(':'));
                     if (numbers.size() < 3) {
