@@ -42,10 +42,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #endif
 #include <KLocalizedString>
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 
 #include <QApplication>
 #include <QCommandLineOption>
@@ -154,9 +151,6 @@ static void resetConfig()
                     if (f.open(QIODevice::WriteOnly | QIODevice::Text)) {
                         // overwrite local xml config
                         QTextStream out(&f);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                        out.setCodec("UTF-8");
-#endif
                         out << doc2.toString();
                         f.close();
                     }
@@ -170,57 +164,6 @@ static void resetConfig()
     }
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-static void initIconRCC(LinuxPackageType packageType)
-{
-#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
-    const QStringList themes{"/icons/breeze/breeze-icons.rcc", "/icons/breeze-dark/breeze-icons-dark.rcc"};
-    for (const QString &theme : themes) {
-        const QString themePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, theme);
-        if (!themePath.isEmpty()) {
-            const QString iconSubdir = theme.left(theme.lastIndexOf('/'));
-            if (QResource::registerResource(themePath, iconSubdir)) {
-                if (QFileInfo::exists(QLatin1Char(':') + iconSubdir + QStringLiteral("/index.theme"))) {
-                    qDebug() << "Loaded icon theme:" << theme;
-                } else {
-                    qWarning() << "No index.theme found in" << theme;
-                    QResource::unregisterResource(themePath, iconSubdir);
-                }
-            } else {
-                qWarning() << "Invalid rcc file" << theme;
-            }
-        }
-    }
-#else
-    // AppImage
-    if (packageType == LinuxPackageType::AppImage) {
-        QMap<QString, QString> themeMap;
-        themeMap.insert("breeze", "/../icons/breeze/breeze-icons.rcc");
-        themeMap.insert("breeze-dark", "/../icons/breeze-dark/breeze-icons-dark.rcc");
-
-        QMapIterator<QString, QString> i(themeMap);
-        while (i.hasNext()) {
-            i.next();
-            QString themePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, i.value());
-            if (!themePath.isEmpty()) {
-                const QString iconSubdir = "/icons/" + i.key();
-                if (QResource::registerResource(themePath, iconSubdir)) {
-                    if (QFileInfo::exists(QLatin1Char(':') + iconSubdir + QStringLiteral("/index.theme"))) {
-                        qDebug() << "Loaded icon theme:" << i.key();
-                    } else {
-                        qWarning() << "No index.theme found for" << i.key();
-                        QResource::unregisterResource(themePath, iconSubdir);
-                    }
-                } else {
-                    qWarning() << "Invalid rcc file" << i.key();
-                }
-            }
-        }
-    }
-#endif
-}
-#endif
-
 int main(int argc, char *argv[])
 {
     int result = EXIT_SUCCESS;
@@ -228,18 +171,12 @@ int main(int argc, char *argv[])
     ExcHndlInit();
 #endif
     // Force QDomDocument to use a deterministic XML attribute order
-    qSetGlobalQHashSeed(0);
+    QHashSeed::setDeterministicGlobalSeed();
 
 #ifdef CRASH_AUTO_TEST
     Logger::init();
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #if defined(Q_OS_WIN)
     QQuickWindow::setGraphicsApi(QSGRendererInterface::Direct3D11);
 #elif defined(Q_OS_MACOS)
@@ -248,12 +185,9 @@ int main(int argc, char *argv[])
     QQuickWindow::setGraphicsApi(QSGRendererInterface::OpenGL);
     QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL, true);
 #endif
-#endif
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     // Block MLT Qt5 module to prevent crashes
     qputenv("MLT_REPOSITORY_DENY", "libmltqt:libmltglaxnimate");
-#endif
 
 #if defined(Q_OS_WIN)
     QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor);
@@ -261,10 +195,8 @@ int main(int argc, char *argv[])
     // TODO: is it a good option ?
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts, true);
 
-// trigger initialisation of proper icon theme
-#if KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    // trigger initialisation of proper icon theme
     KIconTheme::initTheme();
-#endif
 
     QApplication app(argc, argv);
 
@@ -273,10 +205,8 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-#if HAVE_STYLE_MANAGER
     // trigger initialisation of proper application style
     KStyleManager::initStyle();
-#endif
 
     // Try to detect package type
     LinuxPackageType packageType = getPackageType();
@@ -328,12 +258,12 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Jean-Baptiste Mardelle"), i18n("MLT and KDE SC 4 / KF5 port, main developer and maintainer"), QStringLiteral("jb@kdenlive.org"));
     // active developers with major involvement
     aboutData.addAuthor(i18n("Nicolas Carion"), i18n("Code re-architecture & timeline rewrite (2019)"), QStringLiteral("french.ebook.lover@gmail.com"));
-    aboutData.addAuthor(i18n("Julius Künzel"), i18n("Feature development, packaging, bug fixing"), QStringLiteral("jk.kdedev@smartlab.uber.space"));
+    aboutData.addAuthor(i18n("Julius Künzel"), i18n("Feature development, packaging, bug fixing"), QStringLiteral("julius.kuenzel@kde.org"));
     aboutData.addAuthor(i18n("Vincent Pinon"), i18n("KF5 port, Windows cross-build, packaging, bug fixing"), QStringLiteral("vpinon@kde.org"));
     // other active developers (alphabetical)
     aboutData.addAuthor(i18n("Dan Dennedy"), i18n("MLT maintainer, Bug fixing, etc."), QStringLiteral("dan@dennedy.org"));
     aboutData.addAuthor(i18n("Simon A. Eugster"), i18n("Color scopes, bug fixing, etc."), QStringLiteral("simon.eu@gmail.com"));
-    aboutData.addAuthor(i18n("Eric Jiang"), i18n("Bug fixing and test improvements"), QStringLiteral("jk.kdedev@smartlab.uber.space"));
+    aboutData.addAuthor(i18n("Eric Jiang"), i18n("Bug fixing and test improvements"), QStringLiteral("erjiang@alumni.iu.edu"));
     // non active developers with major improvement (alphabetical)
     aboutData.addAuthor(i18n("Jason Wood"), i18n("Original KDE 3 version author (not active anymore)"), QStringLiteral("jasonwood@blueyonder.co.uk"));
     // non developers (alphabetical)
@@ -465,7 +395,10 @@ int main(int argc, char *argv[])
         int exitCode = EXIT_SUCCESS;
 
         for (const auto &job : renderjobs) {
-            const QStringList argsJob = RenderRequest::argsByJob(job);
+            QStringList argsJob = RenderRequest::argsByJob(job, false);
+            if (parser.value(mltLogLevelOption) == QStringLiteral("debug")) {
+                argsJob << "--debug";
+            }
             qDebug() << "* CREATED JOB WITH ARGS: " << argsJob;
             qDebug() << "starting kdenlive_render process using: " << KdenliveSettings::kdenliverendererpath();
             if (!parser.isSet(exitOption)) {
@@ -495,24 +428,6 @@ int main(int argc, char *argv[])
         return exitCode;
     }
 
-#if defined(Q_OS_WIN)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    KSharedConfigPtr configWin = KSharedConfig::openConfig("kdenliverc");
-    KConfigGroup grp1(configWin, "misc");
-    if (grp1.exists()) {
-        int glMode = grp1.readEntry("opengl_backend", 0);
-        if (glMode > 0) {
-            QCoreApplication::setAttribute((Qt::ApplicationAttribute)glMode, true);
-        }
-    } else {
-        // Default to OpenGLES (QtAngle) on first start
-        QCoreApplication::setAttribute(Qt::AA_UseOpenGLES, true);
-        grp1.writeEntry("opengl_backend", int(Qt::AA_UseOpenGLES));
-    }
-    configWin->sync();
-#endif
-#endif
-
     qApp->processEvents(QEventLoop::AllEvents);
     Splash splash;
     qApp->processEvents(QEventLoop::AllEvents);
@@ -525,10 +440,6 @@ int main(int argc, char *argv[])
     qputenv("PATH", path.toUtf8().constData());
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    initIconRCC(packageType);
-#endif
-
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup grp(config, "unmanaged");
     KConfigGroup uicg(config, "UiSettings");
@@ -542,12 +453,6 @@ int main(int argc, char *argv[])
     KDBusService programDBusService;
 #endif
 
-#if KICONTHEMES_VERSION < QT_VERSION_CHECK(6, 3, 0)
-    bool forceBreeze = grp.readEntry("force_breeze", QVariant(false)).toBool();
-    if (forceBreeze || packageType == LinuxPackageType::AppImage) {
-        QIcon::setThemeName(QStringLiteral("breeze"));
-    }
-#endif
     qApp->processEvents(QEventLoop::AllEvents);
 
 #if defined(KF5_USE_CRASH)
@@ -579,6 +484,11 @@ int main(int argc, char *argv[])
                                      1, 0,                       // major and minor version of the import
                                      "ProjectTool",              // name in QML
                                      "Error: only enums");
+    qmlRegisterUncreatableMetaObject(KeyframeType::staticMetaObject, // static meta object
+                                     "com.enums",                    // import statement
+                                     1, 0,                           // major and minor version of the import
+                                     "KeyframeType",                 // name in QML
+                                     "Error: only enums");
     if (parser.value(mltLogLevelOption) == QStringLiteral("verbose")) {
         mlt_log_set_level(MLT_LOG_VERBOSE);
     } else if (parser.value(mltLogLevelOption) == QStringLiteral("debug")) {
