@@ -31,10 +31,10 @@ static void mlt_log_handler(void *service, int mlt_level, const char *format, va
         char *id = mlt_properties_get(properties, "id");
         if (!resource || resource[0] != '<' || resource[strlen(resource) - 1] != '>') mlt_type = mlt_properties_get(properties, "mlt_type");
         if (service_name)
-            message = QString("[%1 %2 %3] ").arg(mlt_type, service_name, id);
+            message = QStringLiteral("[%1 %2 %3] ").arg(mlt_type, service_name, id);
         else
             message = QString::asprintf("[%s %p] ", mlt_type, service);
-        if (resource) message.append(QString("\"%1\" ").arg(resource));
+        if (resource) message.append(QStringLiteral("\"%1\" ").arg(resource));
         message.append(QString::vasprintf(format, args));
         message.replace('\n', "");
         if (!strcmp(mlt_type, "filter")) {
@@ -277,11 +277,11 @@ void MltConnection::refreshLumas()
     QStringList verticalLumas;
     QStringList squareLumas;
     QStringList allImagefiles;
-    for (const QString &folder : qAsConst(customLumas)) {
+    for (const QString &folder : std::as_const(customLumas)) {
         QDir topDir(folder);
         QStringList folders = topDir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
         QString format;
-        for (const QString &f : qAsConst(folders)) {
+        for (const QString &f : std::as_const(folders)) {
             QStringList imagefiles;
             QDir dir(topDir.absoluteFilePath(f));
             QStringList filesnames;
@@ -292,7 +292,7 @@ void MltConnection::refreshLumas()
             if (MainWindow::m_lumaFiles.contains(format)) {
                 imagefiles = MainWindow::m_lumaFiles.value(format);
             }
-            for (const QString &fname : qAsConst(filesnames)) {
+            for (const QString &fname : std::as_const(filesnames)) {
                 imagefiles.append(dir.absoluteFilePath(fname));
             }
             if (f == QLatin1String("HD")) {
@@ -326,9 +326,5 @@ void MltConnection::refreshLumas()
     MainWindow::m_lumaFiles.insert(QStringLiteral("PAL"), sdLumas);
     MainWindow::m_lumaFiles.insert(QStringLiteral("NTSC"), ntscLumas);
     allImagefiles.removeDuplicates();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QtConcurrent::run(pCore.get(), &Core::buildLumaThumbs, allImagefiles);
-#else
     (void)QtConcurrent::run(&Core::buildLumaThumbs, pCore.get(), allImagefiles);
-#endif
 }
