@@ -52,11 +52,7 @@ public:
     explicit AnalysisTree(QWidget *parent = nullptr);
 
 protected:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QTreeWidgetItem *> &list) const override;
-#else
-    QMimeData *mimeData(const QList<QTreeWidgetItem *> list) const override;
-#endif
 };
 
 /** @class ClipPropertiesController
@@ -130,6 +126,8 @@ private:
     void fillProperties();
     /** @brief Add/remove icon beside audio stream to indicate effects. */
     void updateStreamIcon(int row, int streamIndex);
+    /** @brief Create a rotated icon to display in side tabs. */
+    QIcon rotatedIcon(const QSize iconSize, const QString &iconName);
 
 Q_SIGNALS:
     void updateClipProperties(const QString &, const QMap<QString, QString> &, const QMap<QString, QString> &);
