@@ -18,9 +18,9 @@ public:
     virtual ~D3DVideoWidget();
 
 public Q_SLOTS:
-    virtual void initialize();
-    virtual void beforeRendering();
-    virtual void renderVideo();
+    void initialize() override;
+    void beforeRendering() override;
+    void renderVideo() override;
 
 private:
     enum Stage { VertexStage, FragmentStage };
