@@ -110,11 +110,15 @@ public Q_SLOTS:
     void slotExtractCurrentFrameToProject();
     /** @brief Refresh monitor background color */
     void updateBgColor();
+    /** @brief Refresh monitor grid */
+    void updateGrid();
     /** @brief Start multitrack operation */
     void slotStartMultiTrackMode();
     /** @brief Stop multitrack operation */
     void slotStopMultiTrackMode();
     void slotPerformMultiTrackMode();
+    /** @brief Indicates the monitor needs a refresh on next activation */
+    void markMonitorDirty(Kdenlive::MonitorId name, const QUuid uuid);
 
 private Q_SLOTS:
     /** @brief Set MLT's consumer deinterlace method */
