@@ -8,11 +8,7 @@
 #pragma once
 
 #include "definitions.h"
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include "videowidget.h"
-#else // Qt6
-#include "glwidget.h"
-#endif
 #include <QImage>
 #include <QObject>
 #include <QUrl>
@@ -160,10 +156,12 @@ Q_SIGNALS:
     void overlayTypeChanged();
     void showGridChanged();
     void gridChanged();
-    void seekNextKeyframe();
-    void seekPreviousKeyframe();
     void addRemoveKeyframe();
-    void seekToKeyframe();
+    /** @brief Seek to an effect keyframe
+     *  @param ix the index of the keyframe we want to reach
+     *  @param offset if offset != 0, the ix param is ignored and we seek to previous (-1) or next(+1) keyframe
+     */
+    void seekToKeyframe(int ix, int offset);
     void clipHasAVChanged();
     void clipNameChanged();
     void clipStreamChanged();
