@@ -610,7 +610,7 @@ bool ArchiveWidget::slotStartArchiving(bool firstPass)
     proxy_only->setEnabled(false);
     timeline_archive->setEnabled(false);
     buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
-    buttonBox->button(QDialogButtonBox::Close)->setText(i18n("Abort"));
+    buttonBox->button(QDialogButtonBox::Close)->setEnabled(false);
 
     bool isArchive = compressed_archive->isChecked();
     if (!firstPass) {
@@ -807,13 +807,14 @@ void ArchiveWidget::slotArchivingFinished(KJob *job, bool finished)
             } else {
                 slotJobResult(false, i18n("There was an error processing project file"));
             }
-            buttonBox->button(QDialogButtonBox::Close)->setText(i18n("Close"));
+            buttonBox->button(QDialogButtonBox::Close)->setEnabled(true);
         } else {
             processProjectFile();
         }
     } else {
         m_copyJob = nullptr;
         slotJobResult(false, i18n("There was an error while copying the files: %1", job->errorString()));
+        buttonBox->button(QDialogButtonBox::Close)->setEnabled(true);
     }
 
     if (!compressed_archive->isChecked()) {
@@ -1189,7 +1190,7 @@ void ArchiveWidget::slotArchivingBoolFinished(bool result, const QString &errorS
             files_list->topLevelItem(i)->child(j)->setDisabled(false);
         }
     }
-    buttonBox->button(QDialogButtonBox::Close)->setText(i18n("Close"));
+    buttonBox->button(QDialogButtonBox::Close)->setEnabled(true);
 }
 
 void ArchiveWidget::slotArchivingIntProgress(int p)
