@@ -28,7 +28,9 @@ private:
     QString m_importAdapters;
     QString m_exportAdapters;
 
-public slots:
+    QString getOtioBinary();
+
+public Q_SLOTS:
     void slotExportProject();
     void slotImportProject();
 };
