@@ -185,25 +185,44 @@ QString SpeechToTextWhisper::speechScript()
 
 bool SpeechToTextWhisper::installNewModel(const QString &modelName)
 {
+    // Ensure models folder exists
+    const QString folder = modelFolder(true, true);
     WhisperDownload d(this, modelName, QApplication::activeWindow());
     d.exec();
     bool installedNew = d.newModelsInstalled();
     return installedNew;
 }
 
-const QString SpeechToTextWhisper::modelFolder(bool mainFolder)
+const QString SpeechToTextWhisper::modelFolder(bool mainFolder, bool create)
 {
     QString folder;
     if (mainFolder) {
         folder = KdenliveSettings::whisperModelFolder();
         if (folder.isEmpty() || !QFileInfo::exists(folder)) {
-            folder = QStandardPaths::locate(QStandardPaths::HomeLocation, QStringLiteral("/.cache/whisper"), QStandardPaths::LocateDirectory);
+            bool useXdgPath = !qgetenv("XDG_CACHE_HOME").isEmpty();
+            if (create) {
+                if (useXdgPath) {
+                    QDir dir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
+                    dir.mkpath("/whisper");
+                    qDebug() << "Created whisper XDG models folder: " << dir.absolutePath();
+                } else {
+                    // On Windows / Mac, whisper downloads in $HOME/.cache
+                    QDir dir(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+                    dir.mkpath("/.cache/whisper");
+                    qDebug() << "Created whisper models folder: " << dir.absolutePath();
+                }
+            }
+            if (useXdgPath) {
+                folder = QStandardPaths::locate(QStandardPaths::GenericCacheLocation, QStringLiteral("/whisper"), QStandardPaths::LocateDirectory);
+            } else {
+                folder = QStandardPaths::locate(QStandardPaths::HomeLocation, QStringLiteral("/.cache/whisper"), QStandardPaths::LocateDirectory);
+            }
         }
     } else {
         folder = QStandardPaths::locate(QStandardPaths::HomeLocation, QStringLiteral("/.cache/huggingface/hub/models--facebook--seamless-m4t-v2-large"),
                                         QStandardPaths::LocateDirectory);
     }
-    if (folder.isEmpty() || !QFileInfo::exists(folder)) {
+    if (folder.isEmpty()) {
         // No folder found for whisper models
         return {};
     }
