@@ -98,6 +98,7 @@ public:
     friend class ProjectManager;
     template <typename T> friend class MoveableItem;
     friend class ClipModel;
+    friend class ClipDurationDialog;
     friend class CompositionModel;
     friend class GroupsModel;
     friend class TimelineController;
@@ -166,6 +167,7 @@ public:
         ItemIdRole,
         ThumbsFormatRole,   /// track only
         EffectNamesRole,    /// track and clip only
+        EffectCountRole,    /// track and clip only
         EffectsEnabledRole, /// track and clip only
         GrabbedRole,        /// clip+composition only
         SelectedRole,       /// clip+composition only
@@ -226,6 +228,7 @@ public:
 
     Q_INVOKABLE int getCompositionPosition(int compoId) const;
     int getSubtitlePosition(int subId) const;
+    int getSubtitleLayer(int subId) const;
     int getCompositionPlaytime(int compoId) const;
     int getCompositionEnd(int compoId) const;
     std::pair<int, int> getMixInOut(int cid) const;
@@ -277,6 +280,9 @@ public:
     /** @brief Helper function that returns true if the given ID is in a group */
     Q_INVOKABLE bool isInGroup(int id) const;
 
+    /** @brief Returns all basic infos about a clip (position, crop, trackId, ...) */
+    ItemInfo getItemInfo(int id) const;
+
     /** @brief Given a composition Id, returns its underlying parameter model */
     std::shared_ptr<AssetParameterModel> getCompositionParameterModel(int compoId) const;
     /** @brief Given a clip Id, returns its underlying effect stack model */
@@ -411,13 +417,14 @@ public:
     */
     Q_INVOKABLE bool requestClipMove(int clipId, int trackId, int position, bool moveMirrorTracks = true, bool updateView = true, bool logUndo = true,
                                      bool invalidateTimeline = false, bool revertMove = false);
-    Q_INVOKABLE bool requestSubtitleMove(int clipId, int position, bool updateView = true, bool logUndo = true, bool finalMove = false, bool fakeMove = false);
-    bool requestSubtitleMove(int clipId, int position, bool updateView, bool first, bool last, bool finalMove, Fun &undo, Fun &redo);
+    Q_INVOKABLE bool requestSubtitleMove(int clipId, int layer, int position, bool updateView = true, bool logUndo = true, bool finalMove = false,
+                                         bool fakeMove = false);
+    bool requestSubtitleMove(int clipId, int layer, int position, bool updateView, bool first, bool last, bool finalMove, Fun &undo, Fun &redo);
     /** @brief return the previous blank frame on a track */
     Q_INVOKABLE int getPreviousBlank(int trackId, int pos);
     /** @brief return the next blank frame on a track */
     Q_INVOKABLE int getNextBlank(int trackId, int pos);
-    int cutSubtitle(int position, Fun &undo, Fun &redo);
+    int cutSubtitle(int layer, int position, Fun &undo, Fun &redo);
     bool requestClipMix(const QString &mixId, std::pair<int, int> clipIds, std::pair<int, int> mixDurations, int trackId, int position, bool updateView,
                         bool invalidateTimeline, bool finalMove, Fun &undo, Fun &redo, bool groupMove);
 
@@ -457,7 +464,7 @@ public:
     Q_INVOKABLE QVariantList suggestItemMove(int itemId, int trackId, int position, int cursorPosition, int snapDistance = -1, bool fakeMove = false);
     Q_INVOKABLE QVariantList suggestClipMove(int clipId, int trackId, int position, int cursorPosition, int snapDistance = -1, bool moveMirrorTracks = true,
                                              bool fakeMove = false);
-    Q_INVOKABLE int suggestSubtitleMove(int subId, int position, int cursorPosition, int snapDistance, bool fakeMove = false);
+    Q_INVOKABLE int suggestSubtitleMove(int subId, int newLayer, int position, int cursorPosition, int snapDistance, bool fakeMove = false);
     Q_INVOKABLE QVariantList suggestCompositionMove(int compoId, int trackId, int position, int cursorPosition, int snapDistance = -1, bool fakeMove = false);
     /** @brief returns the frame pos adjusted to edit mode
      */
@@ -787,7 +794,7 @@ public:
 
     /** @brief Get a timeline clip id by its position or -1 if not found
      */
-    int getClipByPosition(int trackId, int position, int playlist = -1) const;
+    int getClipByPosition(int trackId, int position, int playlistOrLayer = -1) const;
     int getClipByStartPosition(int trackId, int position) const;
 
     /** @brief Get a timeline composition id by its starting position or -1 if not found
@@ -795,8 +802,8 @@ public:
     int getCompositionByPosition(int trackId, int position) const;
     /** @brief Get a timeline subtitle id by its starting position or -1 if not found
      */
-    int getSubtitleByStartPosition(int position) const;
-    int getSubtitleByPosition(int position) const;
+    int getSubtitleByStartPosition(int layer, int position) const;
+    int getSubtitleByPosition(int layer, int position) const;
 
     /** @brief Returns a list of all items that are intersect with a given range.
      * @param trackId is the id of the track for concerned items. Setting trackId to -1 returns items on all tracks
