@@ -6,8 +6,12 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
-#include "widgets/timecodedisplay.h"
+#include "definitions.h"
 #include "ui_clipdurationdialog_ui.h"
+#include "widgets/timecodedisplay.h"
+#include <unordered_set>
+
+class TimelineItemModel;
 
 /** @class ClipDurationDialog
     @brief A dialog for modifying an item's (clip or transition) duration.
@@ -18,7 +22,7 @@ class ClipDurationDialog : public QDialog, public Ui::ClipDurationDialog_UI
     Q_OBJECT
 
 public:
-    explicit ClipDurationDialog(int clipId, int pos, int minpos, int in, int out, int length, int maxpos, bool rippleMode, QWidget *parent = nullptr);
+    explicit ClipDurationDialog(std::shared_ptr<TimelineItemModel> timeline, std::unordered_set<int> clipIds, QWidget *parent = nullptr);
     GenTime startPos() const;
     GenTime cropStart() const;
     GenTime duration() const;
@@ -28,12 +32,13 @@ private Q_SLOTS:
     void slotCheckStart();
     void slotCheckCrop();
     void slotCheckEnd();
+    void accept() override;
 
 private:
-    int m_clipId;
+    std::unordered_set<int> m_itemIds;
     double m_fps;
-    GenTime m_min;
-    GenTime m_max;
-    GenTime m_crop;
-    GenTime m_length;
+    int m_minPos{-1};
+    int m_maxPos{-1};
+    std::shared_ptr<TimelineItemModel> m_model;
+    ItemInfo m_firstItemInfo;
 };
