@@ -170,7 +170,7 @@ void PreviewManager::loadChunks(QVariantList previewChunks, QVariantList dirtyCh
         }
         int position = playlist.clip_start(i);
         if (previewChunks.contains(QString::number(position))) {
-            if (existingChuncks.contains(QString("%1.%2").arg(position).arg(m_extension))) {
+            if (existingChuncks.contains(QStringLiteral("%1.%2").arg(position).arg(m_extension))) {
                 clip.reset(playlist.get_clip(i));
                 m_renderedChunks << position;
                 m_previewTrack->insert_at(position, clip.get(), 1);
@@ -184,7 +184,7 @@ void PreviewManager::loadChunks(QVariantList previewChunks, QVariantList dirtyCh
     if (!dirtyChunks.isEmpty()) {
         std::sort(dirtyChunks.begin(), dirtyChunks.end(), chunkSort);
         QMutexLocker lock(&m_dirtyMutex);
-        for (const auto &i : qAsConst(dirtyChunks)) {
+        for (const auto &i : std::as_const(dirtyChunks)) {
             if (!m_dirtyChunks.contains(i)) {
                 m_dirtyChunks << i;
             }
@@ -433,7 +433,7 @@ void PreviewManager::clearPreviewRange(bool resetZones)
     m_tractor->lock();
     bool hasPreview = m_previewTrack != nullptr;
     QMutexLocker lock(&m_dirtyMutex);
-    for (const auto &ix : qAsConst(m_renderedChunks)) {
+    for (const auto &ix : std::as_const(m_renderedChunks)) {
         m_cacheDir.remove(QStringLiteral("%1.%2").arg(ix.toInt()).arg(m_extension));
         if (!m_dirtyChunks.contains(ix)) {
             m_dirtyChunks << ix;
@@ -495,7 +495,7 @@ void PreviewManager::addPreviewRange(const QPoint zone, bool add)
         abortRendering();
         m_tractor->lock();
         bool hasPreview = m_previewTrack != nullptr;
-        for (int ix : qAsConst(toRemove)) {
+        for (int ix : std::as_const(toRemove)) {
             m_cacheDir.remove(QStringLiteral("%1.%2").arg(ix).arg(m_extension));
             if (!hasPreview) {
                 continue;
@@ -656,7 +656,7 @@ void PreviewManager::slotRemoveInvalidUndo(int ix)
     }
     QStringList dirs = m_undoDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
     bool ok;
-    for (const QString &dir : qAsConst(dirs)) {
+    for (const QString &dir : std::as_const(dirs)) {
         if (dir.toInt(&ok) >= ix && ok) {
             QDir tmp = m_undoDir;
             if (tmp.cd(dir)) {
@@ -772,8 +772,7 @@ void PreviewManager::gotPreviewRender(int frame, const QString &file, int progre
         if (progress < 0) {
             if (m_warnOnCrash) {
                 pCore->displayMessage(i18n("Preview rendering failed, check your parameters. %1Show details...%2",
-                                           QString("<a href=\"" + QString::fromLatin1(QUrl::toPercentEncoding(file)) + QStringLiteral("\">")),
-                                           QStringLiteral("</a>")),
+                                           QStringLiteral("<a href=\"%1\">").arg(QUrl::toPercentEncoding(file)), QStringLiteral("</a>")),
                                       MltError);
             } else {
                 // TODO display info about stopped preview job
@@ -782,7 +781,7 @@ void PreviewManager::gotPreviewRender(int frame, const QString &file, int progre
         return;
     }
     if (m_previewTrack->is_blank_at(frame)) {
-        Mlt::Producer prod(pCore->getProjectProfile(), QString("avformat:%1").arg(file).toUtf8().constData());
+        Mlt::Producer prod(pCore->getProjectProfile(), QStringLiteral("avformat:%1").arg(file).toUtf8().constData());
         if (prod.is_valid() && prod.get_length() == KdenliveSettings::timelinechunks()) {
             m_dirtyMutex.lock();
             m_dirtyChunks.removeAll(QVariant(frame));
@@ -858,7 +857,7 @@ const QStringList PreviewManager::getCompressedList(const QVariantList items) co
         if (current - KdenliveSettings::timelinechunks() == lastFrame) {
             lastFrame = current;
             if (frame == items.last()) {
-                currentString.append(QString("-%1").arg(lastFrame));
+                currentString.append(QStringLiteral("-%1").arg(lastFrame));
                 resultString << currentString;
                 currentString.clear();
             }
@@ -872,7 +871,7 @@ const QStringList PreviewManager::getCompressedList(const QVariantList items) co
             currentString = frame.toString();
         } else {
             // Range, store
-            currentString.append(QString("-%1").arg(lastFrame));
+            currentString.append(QStringLiteral("-%1").arg(lastFrame));
             resultString << currentString;
             currentString = frame.toString();
         }
