@@ -156,7 +156,7 @@ const QList<QUrl> ThumbnailCache::getAudioThumbPath(const QString &binId) const
     QDir thumbFolder = getDir(true, &ok);
     QList<QUrl> pathList;
     if (ok) {
-        for (const QString &p : qAsConst(key)) {
+        for (const QString &p : std::as_const(key)) {
             if (thumbFolder.exists(p)) {
                 pathList << QUrl::fromLocalFile(thumbFolder.absoluteFilePath(p));
             }
@@ -170,7 +170,7 @@ QImage ThumbnailCache::getThumbnail(QString hash, const QString &binId, int pos,
     if (hash.isEmpty()) {
         return QImage();
     }
-    hash.append(QString("#%1.jpg").arg(pos));
+    hash.append(QStringLiteral("#%1.jpg").arg(pos));
     QMutexLocker locker(&m_mutex);
     if (m_volatileCache->contains(hash)) {
         return m_volatileCache->get(hash);
@@ -363,8 +363,8 @@ QStringList ThumbnailCache::getAudioKey(const QString &binId, bool *ok)
             QList<int> streamIxes = binClip->audioStreams().keys();
             if (streamIxes.size() > 1) {
                 QStringList streamsList;
-                for (const int st : qAsConst(streamIxes)) {
-                    streamsList << QString("%1_%2.png").arg(binClip->hash()).arg(st);
+                for (const int st : std::as_const(streamIxes)) {
+                    streamsList << QStringLiteral("%1_%2.png").arg(binClip->hash()).arg(st);
                 }
                 return streamsList;
             }
@@ -372,14 +372,14 @@ QStringList ThumbnailCache::getAudioKey(const QString &binId, bool *ok)
         if (streams.size() < 2) {
             int audio = binClip->getProducerIntProperty(QStringLiteral("audio_index"));
             if (audio > -1) {
-                return {QString("%1_%2.png").arg(binClip->hash()).arg(audio)};
+                return {QStringLiteral("%1_%2.png").arg(binClip->hash()).arg(audio)};
             }
             return {binClip->hash() + QStringLiteral(".png")};
         }
         QStringList streamsList;
         QStringList streamIndexes = streams.split(QLatin1Char(';'));
-        for (const QString &st : qAsConst(streamIndexes)) {
-            streamsList << QString("%1_%2.png").arg(binClip->hash(), st);
+        for (const QString &st : std::as_const(streamIndexes)) {
+            streamsList << QStringLiteral("%1_%2.png").arg(binClip->hash(), st);
         }
         return streamsList;
     }
