@@ -143,27 +143,13 @@ int Timecode::getFrameCount(const QString &duration) const
     int offset = 0;
     if (duration.at(0) == '-') {
         offset = 1;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        hours = duration.midRef(1, 2).toInt();
-#else
         hours = QStringView(duration).mid(1, 2).toInt();
-#endif
     } else {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        hours = duration.leftRef(2).toInt();
-#else
         hours = QStringView(duration).left(2).toInt();
-#endif
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    minutes = duration.midRef(3 + offset, 2).toInt();
-    seconds = duration.midRef(6 + offset, 2).toInt();
-    frames = duration.rightRef(duration.length() - 9 - offset).toInt();
-#else
     minutes = QStringView(duration).mid(3 + offset, 2).toInt();
     seconds = QStringView(duration).mid(6 + offset, 2).toInt();
     frames = QStringView(duration).right(duration.length() - 9 - offset).toInt();
-#endif
     if (m_dropFrameTimecode) {
         // CONVERT DROP FRAME TIMECODE TO A FRAME NUMBER
         // Code by David Heidelberger, adapted from Andrew Duncan
@@ -237,13 +223,13 @@ QString Timecode::getStringTimecode(int frames, const double &fps, bool showFram
     seconds = seconds % 60;
     int hours = minutes / 60;
     minutes = minutes % 60;
-    QString text = showFrames
-                       ? QString("%1:%2:%3.%4")
-                             .arg(hours, 2, 10, QLatin1Char('0'))
-                             .arg(minutes, 2, 10, QLatin1Char('0'))
-                             .arg(seconds, 2, 10, QLatin1Char('0'))
-                             .arg(frms, fps > 100 ? 3 : 2, 10, QLatin1Char('0'))
-                       : QString("%1:%2:%3").arg(hours, 2, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
+    QString text =
+        showFrames ? QStringLiteral("%1:%2:%3.%4")
+                         .arg(hours, 2, 10, QLatin1Char('0'))
+                         .arg(minutes, 2, 10, QLatin1Char('0'))
+                         .arg(seconds, 2, 10, QLatin1Char('0'))
+                         .arg(frms, fps > 100 ? 3 : 2, 10, QLatin1Char('0'))
+                   : QStringLiteral("%1:%2:%3").arg(hours, 2, 10, QLatin1Char('0')).arg(minutes, 2, 10, QLatin1Char('0')).arg(seconds, 2, 10, QLatin1Char('0'));
     if (negative) {
         text.prepend('-');
     }
@@ -278,7 +264,7 @@ const QString Timecode::getTimecodeHH_MM_SS_FF(int frames) const
 
     int seconds = frames / m_realFps;
     frames -= ceil(seconds * m_realFps);
-    QString text = QString("%1:%2:%3:%4")
+    QString text = QStringLiteral("%1:%2:%3:%4")
                        .arg(hours, 2, 10, QLatin1Char('0'))
                        .arg(minutes, 2, 10, QLatin1Char('0'))
                        .arg(seconds, 2, 10, QLatin1Char('0'))
@@ -306,7 +292,7 @@ const QString Timecode::getTimecodeHH_MM_SS_HH(const GenTime &time) const
     int hours = minutes / 60;
     minutes = minutes % 60;
 
-    QString text = QString("%1:%2:%3%5%4")
+    QString text = QStringLiteral("%1:%2:%3%5%4")
                        .arg(hours, 2, 10, QLatin1Char('0'))
                        .arg(minutes, 2, 10, QLatin1Char('0'))
                        .arg(seconds, 2, 10, QLatin1Char('0'))
@@ -360,7 +346,7 @@ const QString Timecode::getTimecodeDropFrame(int framenumber) const
     int minutes = (int)floor(floor(framenumber / m_displayedFramesPerSecond) / 60) % 60;
     int hours = floor(floor(floor(framenumber / m_displayedFramesPerSecond) / 60) / 60);
 
-    QString text = QString("%1:%2:%3,%4")
+    QString text = QStringLiteral("%1:%2:%3,%4")
                        .arg(hours, 2, 10, QLatin1Char('0'))
                        .arg(minutes, 2, 10, QLatin1Char('0'))
                        .arg(seconds, 2, 10, QLatin1Char('0'))
