@@ -33,7 +33,7 @@ ChooseColorWidget::ChooseColorWidget(QWidget *parent, const QColor &color, bool
     connect(picker, &ColorPickerWidget::disableCurrentFilter, this, &ChooseColorWidget::disableCurrentFilter);
     connect(m_button, &KColorButton::changed, this, &ChooseColorWidget::modified);
 
-    setMinimumHeight(m_button->sizeHint().height());
+    setFixedHeight(m_button->sizeHint().height());
 }
 
 QColor ChooseColorWidget::color() const
