@@ -12,7 +12,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QToolButton>
 
 DoubleWidget::DoubleWidget(const QString &name, double value, double min, double max, double factor, double defaultValue, const QString &comment, int id,
-                           const QString &suffix, int decimals, bool oddOnly, QWidget *parent)
+                           const QString &suffix, int decimals, bool oddOnly, bool compact, QWidget *parent)
     : QWidget(parent)
     , m_factor(factor)
 {
@@ -20,7 +20,8 @@ DoubleWidget::DoubleWidget(const QString &name, double value, double min, double
     auto *layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
-    m_dragVal = new DragValue(name, defaultValue * m_factor, decimals, min, max, id, suffix, true, oddOnly, this);
+    m_dragVal = new DragValue(name, defaultValue * m_factor, decimals, min, max, id, suffix, !compact, oddOnly, this);
+    layout->addWidget(m_dragVal);
     if (suffix == QStringLiteral("°")) {
         QToolButton *rotationTb = new QToolButton(this);
         rotationTb->setIcon(QIcon::fromTheme("object-rotate-right"));
@@ -36,8 +37,10 @@ DoubleWidget::DoubleWidget(const QString &name, double value, double min, double
             m_dragVal->setValue(val);
         });
     }
-    layout->addWidget(m_dragVal);
-    setMinimumHeight(m_dragVal->height());
+    if (compact) {
+        layout->addStretch(10);
+    }
+    setFixedHeight(m_dragVal->minimumHeight());
 
     if (!comment.isEmpty()) {
         setToolTip(comment);
@@ -46,6 +49,11 @@ DoubleWidget::DoubleWidget(const QString &name, double value, double min, double
     connect(m_dragVal, &DragValue::valueChanged, this, &DoubleWidget::slotSetValue);
 }
 
+QLabel *DoubleWidget::createLabel()
+{
+    return m_dragVal->createLabel();
+}
+
 void DoubleWidget::setDragObjectName(const QString &name)
 {
     m_dragVal->setObjectName(name);
